@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Argus files - Arp Procession
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software. Argus files - Arp Processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusArp.c#4 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -200,6 +210,8 @@ ArgusCreateArpFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
             retn->hdr.argus_dsrvl8.len  = sizeof(struct ArgusRarpFlow)/4 + 1;
             retn->hdr.argus_dsrvl8.qual = ARGUS_TYPE_RARP;
 
+            bcopy (TPA(ahdr), &arp_tpa, sizeof(arp_tpa));
+
 #ifdef _LITTLE_ENDIAN
             arp_tpa = ntohl(arp_tpa);
 #endif
@@ -244,7 +256,7 @@ ArgusCreateArpFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
 
 out:
 #ifdef ARGUSDEBUG
-   ArgusDebug (8, "ArgusCreateArpFlow (%p) returning %p\n", ep, retn);
+   ArgusDebug (8, "ArgusCreateArpFlow (0x%x) returning %d\n", ep, retn);
 #endif
 
    return (retn);
