@@ -1,18 +1,20 @@
 /*
- * Argus Software.  Argus files - Modeler
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software. Argus files - Events processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,6 +24,12 @@
  *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusEvents.c#10 $
+ * $DateTime: 2016/10/03 10:25:27 $
+ * $Change: 3209 $
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
 #endif
@@ -76,6 +84,25 @@ ArgusNewEvents ()
    return (retn);
 }
 
+void
+ArgusDeleteEvents (struct ArgusEventsStruct *events)
+{
+   struct ArgusEventsStruct *retn = NULL;
+
+   if (events != NULL) {
+      pthread_mutex_destroy(&events->lock);
+      if (events->ArgusEventsList != NULL) {
+         ArgusDeleteList (events->ArgusEventsList, ARGUS_EVENT_LIST);
+         events->ArgusEventsList =  NULL;
+      }
+      ArgusFree (events);
+   }
+
+#ifdef ARGUSDEBUG
+   ArgusDebug (1, "ArgusDeleteEvents() returning retn 0x%x\n", retn);
+#endif
+}
+
 
 
 void
@@ -86,7 +113,7 @@ ArgusInitEvents (struct ArgusEventsStruct *events)
 
    events->ArgusModel      = ArgusModel;
    events->ArgusSrc        = ArgusSourceTask;
-   events->ArgusOutputList = ArgusOutputTask->ArgusOutputList;
+   events->ArgusOutputList = ArgusOutputTask->ArgusInputList;
 
 #if defined(ARGUS_THREADS)
    if ((events->ArgusEventsList != NULL) && (!(ArgusListEmpty(events->ArgusEventsList))))
@@ -106,8 +133,11 @@ ArgusCloseEvents (struct ArgusEventsStruct *events)
       events->status |= ARGUS_SHUTDOWN;
 
 #if defined(ARGUS_THREADS)
-      if (events->thread)
+      if (events->thread) {
          pthread_cancel(events->thread);
+         pthread_join(events->thread, NULL);
+         events->thread = 0;
+      }
 #endif
    }
 
@@ -387,9 +417,11 @@ struct ArgusRecord {
 };
 */
    if (cnt > 0) {
+      struct ArgusSourceStruct      *src = events->ArgusSrc;
       struct ArgusTimeObject       *time = &rec->argus_event.time;
       struct ArgusTransportStruct *trans = &rec->argus_event.trans;
       struct ArgusDataStruct       *data = &rec->argus_event.data;
+      char *inf = NULL;
       int tlen = 1;
 
       gettimeofday(&now, 0L);
@@ -398,27 +430,64 @@ struct ArgusRecord {
       time->hdr.subtype            = ARGUS_TIME_ABSOLUTE_TIMESTAMP | ARGUS_TIME_SRC_START | ARGUS_TIME_SRC_END;
       time->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_UTC_MICROSECONDS;
       time->hdr.argus_dsrvl8.len   = 5;
-      tlen += time->hdr.argus_dsrvl8.len;
+      tlen                        += time->hdr.argus_dsrvl8.len;
 
       retn->dsrs[ARGUS_TIME_INDEX] = &time->hdr;
-      retn->dsrindex |= 1 << ARGUS_TIME_INDEX;
-
-      time->src.start.tv_sec  = then.tv_sec;
-      time->src.start.tv_usec = then.tv_usec;
-      time->src.end.tv_sec    = now.tv_sec;
-      time->src.end.tv_usec   = now.tv_usec;
+      retn->dsrindex              |= 1 << ARGUS_TIME_INDEX;
 
+      time->src.start.tv_sec       = then.tv_sec;
+      time->src.start.tv_usec      = then.tv_usec;
+      time->src.end.tv_sec         = now.tv_sec;
+      time->src.end.tv_usec        = now.tv_usec;
+      
       trans->hdr.type              = ARGUS_TRANSPORT_DSR;
       trans->hdr.subtype           = ARGUS_SRCID | ARGUS_SEQ;
-      trans->hdr.argus_dsrvl8.qual = events->ArgusSrc->type;
-      trans->hdr.argus_dsrvl8.len  = 3;
-      tlen += trans->hdr.argus_dsrvl8.len;
+      trans->hdr.argus_dsrvl8.qual = src->type & ~ARGUS_TYPE_INTERFACE;
+
+      switch (src->type & ~ARGUS_TYPE_INTERFACE) {
+         case ARGUS_TYPE_STRING: {
+            tlen = strlen((const char *)&src->trans.srcid.a_un.str);
+            bcopy(&src->trans.srcid.a_un.str, trans->srcid.a_un.str, tlen);
+            break;
+         }
+         case ARGUS_TYPE_INT: {
+            tlen = sizeof(src->trans.srcid.a_un.value);
+            trans->srcid.a_un.value = src->trans.srcid.a_un.value;
+            break;
+         }
+         case ARGUS_TYPE_IPV4: {
+            tlen = sizeof(src->trans.srcid.a_un.ipv4);
+            trans->srcid.a_un.ipv4 = src->trans.srcid.a_un.ipv4;
+            break;
+         }
+         case ARGUS_TYPE_IPV6: {
+            tlen = sizeof(src->trans.srcid.a_un.ipv6);
+            bcopy(&src->trans.srcid.a_un.ipv6, trans->srcid.a_un.ipv6, tlen);
+            break;
+         }
+
+         case ARGUS_TYPE_UUID  : {
+            tlen = sizeof(src->trans.srcid.a_un.uuid);
+            bcopy(&src->trans.srcid.a_un.uuid, trans->srcid.a_un.uuid, tlen);
+            break;
+         }
+      }
+
+      if ((inf = getArgusManInf(src)) != NULL) {
+         trans->hdr.argus_dsrvl8.qual |= ARGUS_TYPE_INTERFACE;
+         bcopy("evt0", &trans->srcid.inf, 4);
+         tlen +=4;
+      }
+
+      trans->seqnum                = events->ArgusSrc->ArgusModel->ArgusSeqNum++;
+      trans->hdr.argus_dsrvl8.len  = tlen + 2;
 
       retn->dsrs[ARGUS_TRANSPORT_INDEX] = &trans->hdr;
       retn->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
 
-      trans->srcid.a_un.value      = getArgusID(events->ArgusSrc);
-      trans->seqnum                = events->ArgusSrc->ArgusModel->ArgusSeqNum++;
+
+
+      tlen                        += trans->hdr.argus_dsrvl8.len;
 
       data->hdr.type               = ARGUS_DATA_DSR;
       data->hdr.subtype            = ARGUS_LEN_16BITS | ARGUS_SRC_DATA;
