@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Argus files - Fragment processing
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software. Argus files - Fragment processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusFrag.c#4 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -321,8 +331,9 @@ ArgusUpdateFRAGState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *
          case ETHERTYPE_IPV6: {
             struct ip6_frag *tfrag = model->ArgusThisIpv6Frag;
             struct ip6_hdr  *iphdr = (struct ip6_hdr *)model->ArgusThisIpHdr;
-            if (!(tfrag->ip6f_offlg & IP6F_MORE_FRAG))
-               frag->totlen = (ntohs(tfrag->ip6f_offlg & IP6F_OFF_MASK) + (ntohs(iphdr->ip6_plen) - 8));
+            if (!(tfrag->ip6f_offlg & IP6F_MORE_FRAG)) {
+               frag->totlen = (ntohs(tfrag->ip6f_offlg & IP6F_OFF_MASK) + (ntohs(iphdr->ip6_plen) - 16));
+            }
             break;
          }
       }
@@ -449,20 +460,39 @@ ArgusUpdateParentFlow (struct ArgusModelerStruct *model, struct ArgusFlowStruct
                   struct ArgusIPAttrStruct *attr = (struct ArgusIPAttrStruct *) parent->dsrs[ARGUS_IPATTR_INDEX];
 
                   if ((parent->state & ARGUS_DIRECTION) != (flowstr->state & ARGUS_DIRECTION)) {
-                     metrics->dst.pkts  += flowstr->canon.metric.src.pkts;
-                     metrics->dst.bytes += flowstr->canon.metric.src.bytes;
+                     if (flowstr->canon.metric.src.pkts) {
+                        metrics->dst.pkts     += flowstr->canon.metric.src.pkts;
+                        metrics->dst.bytes    += flowstr->canon.metric.src.bytes;
+                        metrics->dst.appbytes += flowstr->canon.metric.src.bytes;
                      
-                     flowstr->canon.metric.src.pkts = 0;
-                     flowstr->canon.metric.src.bytes = 0;
+                        flowstr->canon.metric.src.pkts = 0;
+                        flowstr->canon.metric.src.bytes = 0;
+                     } else {
+                        metrics->src.pkts     += flowstr->canon.metric.dst.pkts;
+                        metrics->src.bytes    += flowstr->canon.metric.dst.bytes;
+                        metrics->src.appbytes += flowstr->canon.metric.dst.bytes;
+                     
+                        flowstr->canon.metric.dst.pkts = 0;
+                        flowstr->canon.metric.dst.bytes = 0;
+                     }
 
                      if (attr != NULL)
                         attr->hdr.argus_dsrvl8.qual |= ARGUS_IPATTR_DST_FRAGMENTS;
 
                   } else {
-                     metrics->src.pkts  += flowstr->canon.metric.src.pkts;
-                     metrics->src.bytes += flowstr->canon.metric.src.bytes;
-                     flowstr->canon.metric.src.pkts = 0;
-                     flowstr->canon.metric.src.bytes = 0;
+                     if (flowstr->canon.metric.src.pkts) {
+                        metrics->src.pkts     += flowstr->canon.metric.src.pkts;
+                        metrics->src.bytes    += flowstr->canon.metric.src.bytes;
+                        metrics->src.appbytes += flowstr->canon.metric.src.bytes;
+                        flowstr->canon.metric.src.pkts = 0;
+                        flowstr->canon.metric.src.bytes = 0;
+                     } else {
+                        metrics->dst.pkts     += flowstr->canon.metric.dst.pkts;
+                        metrics->dst.bytes    += flowstr->canon.metric.dst.bytes;
+                        metrics->dst.appbytes += flowstr->canon.metric.dst.bytes;
+                        flowstr->canon.metric.dst.pkts = 0;
+                        flowstr->canon.metric.dst.bytes = 0;
+                     }
 
                      if (attr != NULL)
                         attr->hdr.argus_dsrvl8.qual |= ARGUS_IPATTR_SRC_FRAGMENTS;
@@ -486,7 +516,11 @@ ArgusUpdateParentFlow (struct ArgusModelerStruct *model, struct ArgusFlowStruct
 
             if (ptime->hdr.subtype == ARGUS_TIME_ABSOLUTE_TIMESTAMP) {
                ptime->hdr.subtype           = ARGUS_TIME_ABSOLUTE_RANGE;
-               ptime->hdr.argus_dsrvl8.qual = ARGUS_TYPE_UTC_MICROSECONDS;
+#if defined(ARGUS_NANOSECONDS)
+               ptime->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_UTC_NANOSECONDS;
+#else
+               ptime->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_UTC_MICROSECONDS;
+#endif
                ptime->hdr.argus_dsrvl8.len  = 5;
                if ((pstime->start.tv_sec  > ftime->src.start.tv_sec) ||
                   ((pstime->start.tv_sec == ftime->src.start.tv_sec) &&
