@@ -1,18 +1,20 @@
 /*
- * Argus Software.  Argus files - Modeler
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - ISIS flow tracking
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
@@ -22,6 +24,12 @@
  *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusIsis.c#4 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
 #endif
@@ -65,10 +73,11 @@ ArgusCreateEtherFlow (struct ArgusModelerStruct *model, struct ether_header *ep)
 #define ETH_ALEN   6
 #endif
       for (i = 0; i < ETH_ALEN; i++) {
-         if (((unsigned char *)&ep->ether_shost)[i] != ((unsigned char *)&ep->ether_dhost)[i])
+         if (((unsigned char *)&ep->ether_shost)[i] != ((unsigned char *)&ep->ether_dhost)[i]) {
             if (((unsigned char *)&ep->ether_shost)[i] > ((unsigned char *)&ep->ether_dhost)[i])
                dstgteq = 0;
             break;
+         }
       }
 
       if (dstgteq) {
@@ -340,26 +349,6 @@ ArgusUpdateIsisState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *
 void
 ArgusInitializeIsis (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flow)
 {
-/*
-   unsigned char rev = flow->state.rev, dir = flow->state.dir;
-   flow->ArgusTransactionNum = ArgusTransactionNum++;
-                                                                                                                           
-   bzero ((char *)&flow->state, sizeof(flow->state));
-   flow->state.rev = rev;
-   flow->state.dir = dir;
-                                                                                                                           
-   flow->state.src.active.minval = 0x7FFFFFFF;
-   flow->state.dst.active.minval = 0x7FFFFFFF;
-*/
-                                                                                                                           
-   flow->qhdr.lasttime.tv_sec  = 0;
-   flow->qhdr.lasttime.tv_usec = 0;
-
-   if (model->ArgusSrc->ArgusReadingOffLine)
-      flow->qhdr.qtime = ArgusModel->ArgusGlobalTime;
-   else
-      gettimeofday(&flow->qhdr.qtime, 0L);
-                                                                                                                           
    ArgusUpdateFlow (model, flow, ARGUS_START, 1);
 }
 
