@@ -1,28 +1,43 @@
 /*
- * Argus Software.  Argus files - Modeler includes
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Modeler Includes
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusModeler.h#8 $
+ * $DateTime: 2016/02/23 00:04:12 $
+ * $Change: 3099 $
+ */
+
+
 #ifndef ArgusModeler_h
 #define ArgusModeler_h
 
+#define ARGUS_MODELER_CLONE	0x40000
+
 #define ARGUS_MARSTATUSTIMER	"60"
+#define ARGUS_MARINTERFACETIMER	"60"
 #define ARGUS_FARSTATUSTIMER	"5"
 
 #define ARGUS_INITIMEOUT	5
@@ -36,7 +51,7 @@
 
 #define ARGUS_MINSNAPLEN	96
 #define ARGUS_MINIPHDRLEN	20
-#define ARGUS_HASHTABLESIZE	0x10000
+#define ARGUS_HASHTABLESIZE	0x1000000
 
 #define ARGUS_REQUEST		0x01
 #define ARGUS_REPLY		0x02
@@ -81,6 +96,9 @@
 #define ARGUS_ISIS    131
 #define ARGUS_NULLNS  132
 
+#define ARGUS_L2TP_PROTO	384
+#define ARGUS_VXLAN_PROTO	385
+#define ARGUS_GENEVE_PROTO	386
 
 /* True if  "l" bytes of "var" were captured */
 #define BYTESCAPTURED(m, var, l) ((u_char *)&(var) <= m->ArgusThisSnapEnd - (l))
@@ -96,6 +114,8 @@
 
 #define LENCHECK(m, l) { if ((l) > len) goto bad; BYTESCHECK(m, *cp, l); }
 
+#define ARGUS_MAX_PROTOCOLS	512
+
 
 #if defined(ARGUS_THREADS)
 #include <pthread.h>
@@ -160,19 +180,19 @@ struct AHHeader {
 
 struct ArgusHashStruct {
    unsigned int len, hash;
-#if defined(__APPLE_CC__) || defined(__APPLE__)
-   unsigned int pad[2];
+   unsigned int ind;
+   unsigned int pad;
    unsigned int key[24];
-#else
-   unsigned int key[24];
-#endif
 };
  
 struct ArgusHashTableHeader {
    struct ArgusHashTableHeader *nxt, *prv;
    struct ArgusHashTable *htbl;
-   struct ArgusHashStruct hstruct;
    void *object;
+   char pad[32];
+
+   struct ArgusHashStruct hstruct;
+   char pad1[16];
 };
 
 
@@ -182,11 +202,10 @@ struct ArgusHashTable {
    unsigned int size;
    int status;
    int bins, items;
-
+   struct ArgusHashTableHeader **array;
 #if defined(ARGUS_THREADS)
    pthread_mutex_t lock;
 #endif
-   struct ArgusHashTableHeader **array;
 };
 
 #define ARGUS_MAX_MPLS_LABELS	4
@@ -199,6 +218,12 @@ struct ArgusKeyStrokeConf {
    float icr_min, icr_max;
 };
 
+struct ArgusControlProtocols {
+   char tcpport[0x10000];
+   char udpport[0x10000];
+};
+
+
 struct ArgusModelerStruct {
    int state, status;
 #if defined(ARGUS_THREADS)
@@ -208,8 +233,6 @@ struct ArgusModelerStruct {
 
    struct ArgusSourceStruct *ArgusSrc;
    struct ArgusQueueStruct *ArgusStatusQueue;
-   struct ArgusQueueStruct *ArgusTimeOutQueues;
-   struct ArgusQueueStruct *ArgusTimeOutQueue[ARGUSTIMEOUTQS];
    struct ArgusListStruct *ArgusOutputList;
    struct ArgusHashTable *ArgusHashTable;
    struct ArgusSystemFlow  *ArgusThisFlow;
@@ -219,34 +242,45 @@ struct ArgusModelerStruct {
 
    unsigned int ArgusThisInterface;
    unsigned int ArgusThisEncaps;
+   unsigned int ArgusThisEncapsLength;
    unsigned int ArgusThisNetworkFlowType;
-   struct llc *ArgusThisLLC;
    unsigned int ArgusThisAppFlowType;
    int ArgusThisMplsLabelIndex;
    unsigned int ArgusThisMplsLabel;
+   unsigned int ArgusThisVxLanVni;
    unsigned int ArgusThisPacket8021QEncaps;
    unsigned char ArgusFlowType, ArgusFlowKey;
    unsigned short ArgusOptionIndicator;
 
-   int ArgusInProtocol, ArgusThisDir, ArgusTrackDuplicates;
+   int ArgusInProtocol, ArgusMatchProtocol;
+   int ArgusThisDir, ArgusTrackDuplicates;
 
    struct ArgusKeyStrokeConf ArgusKeyStroke;
    struct ArgusUniStats *ArgusThisStats;
  
    struct ether_header *ArgusThisEpHdr;
+   struct argus_llc *ArgusThisLLC;
+   struct argus_gre *ArgusThisGre;
+   struct argus_geneve *ArgusThisGeneve;
 
    void *ArgusThisMacHdr;
    void *ArgusThisIpHdr; 
    struct ip6_frag *ArgusThisIpv6Frag;
    void *ArgusThisNetworkHdr;
 
+   unsigned char *ArgusThisPacket;
    unsigned char *ArgusThisUpHdr;
    unsigned char *ArgusThisSnapEnd;
  
    int ArgusControlMonitor;
+   struct ArgusControlProtocols *cps;
+
+   int ArgusHashTableSize;
+
    int ArgusSnapLength;
    int ArgusGenerateTime;
    int ArgusGeneratePacketSize;
+   int ArgusGeneratePacketSizeHisto;
 
    int ArgusThisLength;
    int ArgusThisBytes;
@@ -295,9 +329,14 @@ struct ArgusModelerStruct {
    int ArgusMinorVersion;
    int ArgusSnapLen;
  
+   int ArgusEncapsCapture;
+   int ArgusTunnelParsing;
+   int ArgusTunnelInfo;
    int ArgusTunnelDiscovery;
+   int ArgusOSFingerPrinting;
    int ArgusUserDataLen;
    int ArgusAflag, ArgusTCPflag, Argusmflag;
+   int ArgusHashflag;
    int ArgusSelfSynchronize, vflag;
 
    int ArgusIPTimeout;
@@ -319,8 +358,12 @@ struct ArgusModelerStruct {
    unsigned int ArgusLocalNet;
    unsigned int ArgusNetMask;
    unsigned int ArgusLink;
+
+   struct ArgusQueueStruct *ArgusTimeOutQueues;
+   struct ArgusQueueStruct *ArgusTimeOutQueue[ARGUSTIMEOUTQS];
 };
 
+
 #include <ArgusUtil.h>
 #include <ArgusSource.h>
 #include <ArgusOutput.h>
@@ -362,12 +405,14 @@ struct ArgusKeyStrokeState {
 
 struct ArgusFlowStruct {
    struct ArgusQueueHeader qhdr;
-   struct ArgusHashTableHeader htblbuf, *htblhdr;
+   struct ArgusHashTableHeader htblbuf;
+   unsigned int state, status, dsrindex;
+   unsigned int ArgusEncaps;
+
+   struct ArgusHashTableHeader *htblhdr;
    struct ArgusDSRHeader *dsrs[ARGUSMAXDSRTYPE];
    struct ArgusQueueStruct frag;
 
-   unsigned int state, status, dsrindex;
-   unsigned int ArgusEncaps;
 
    unsigned short trans, timeout;
    unsigned short userlen;
@@ -380,15 +425,14 @@ struct ArgusFlowStruct {
    struct ArgusCanonRecord canon;
 };
 
-struct erspan_ii_header {
-   u_int16_t ver_vlan;
-   u_int16_t cos_ent_session;
-   u_int32_t resvert_index;
+#define MAX_PORT_ALG_TYPES	4
+struct ArgusTransportRoutines {
+   char *field;
+   int proto;
+   unsigned short type, port;
+   unsigned short (*parse)(struct ArgusModelerStruct *, void *ptr);
 };
 
-#define ERSPAN_VER(x)          ( ntohs(((struct erspan_ii_header *) x)->ver_vlan) >> 12 )
-
-
 #if defined(ArgusModeler)
 
 #if defined(LBL_ALIGN)
@@ -398,7 +442,7 @@ unsigned char ArgusAlignBuffer[ARGUS_MAXALIGNBUF], *ArgusAlignBuf = ArgusAlignBu
 
 struct ArgusModelerStruct *ArgusModel = NULL;
 
-struct llc ArgusThisLLCBuffer;
+struct argus_llc ArgusThisLLCBuffer;
 
 unsigned char argusDSRTypes [ARGUSMAXDSRTYPE] = {
    ARGUS_TRANSPORT_DSR, ARGUS_FLOW_DSR, ARGUS_TIME_DSR,
@@ -411,6 +455,10 @@ struct timeval ArgusQueueInterval = {0, 50000};
 struct timeval ArgusListenTime = {0, 0};
 struct timeval ArgusListenInterval = {0, 250000};
 
+typedef unsigned short (*pproc)(struct ArgusModelerStruct *, void *ptr);
+pproc ArgusTransportParseRoutines [0x10000];
+void ArgusInitTunnelPortNumbers (void);
+
 struct ArgusModelerStruct *ArgusNewModeler(void);
 struct ArgusModelerStruct *ArgusCloneModeler(struct ArgusModelerStruct *);
 
@@ -434,6 +482,7 @@ void ArgusTallyTime (struct ArgusFlowStruct *, unsigned char);
 
 unsigned short ArgusParseIPOptions (unsigned char *, int);
 
+void setArgusHashTableSize (struct ArgusModelerStruct *model, int value);
 void setArgusIpTimeout (struct ArgusModelerStruct *model, int value);
 void setArgusTcpTimeout (struct ArgusModelerStruct *model, int value);
 void setArgusIcmpTimeout (struct ArgusModelerStruct *model, int value);
@@ -442,12 +491,26 @@ void setArgusFragTimeout (struct ArgusModelerStruct *model, int value);
 void setArgusArpTimeout (struct ArgusModelerStruct *model, int value);
 void setArgusOtherTimeout (struct ArgusModelerStruct *model, int value);
 
+void setArgusEncapsCapture (struct ArgusModelerStruct *model, char *);
+int getArgusEncapsCapture (struct ArgusModelerStruct *model);
+
+void setArgusTunnelParsing (struct ArgusModelerStruct *model, char *);
+void setArgusTunnelInformation (struct ArgusModelerStruct *model, char *);
+
+int getArgusHashTableSize (struct ArgusModelerStruct *model);
+
 void setArgusSynchronize (struct ArgusModelerStruct *, int);
 
 int getArgusKeystroke(struct ArgusModelerStruct *);
 void setArgusKeystroke(struct ArgusModelerStruct *, int);
 void setArgusKeystrokeVariable(struct ArgusModelerStruct *, char *);
 
+int getArgusOSFingerPrinting (struct ArgusModelerStruct *);
+void setArgusOSFingerPrinting (struct ArgusModelerStruct *, int);
+
+extern void setArgusPacketCaptureProtocols(struct ArgusDumpStruct *, char *);
+void setArgusControlPlaneProtocols(struct ArgusModelerStruct *, char *);
+
 int getArgusTunnelDiscovery (struct ArgusModelerStruct *);
 void setArgusTunnelDiscovery (struct ArgusModelerStruct *, int);
 
@@ -461,6 +524,8 @@ int getArgusAflag(struct ArgusModelerStruct *);
 void setArgusAflag(struct ArgusModelerStruct *, int);
 int getArgusTCPflag(struct ArgusModelerStruct *);
 void setArgusTCPflag(struct ArgusModelerStruct *, int);
+int getArgusHashflag(struct ArgusModelerStruct *);
+void setArgusHashflag(struct ArgusModelerStruct *, int);
 int getArgusmflag(struct ArgusModelerStruct *);
 void setArgusmflag(struct ArgusModelerStruct *, int);
 int getArgusUserDataLen(struct ArgusModelerStruct *);
@@ -472,6 +537,8 @@ int getArgusGenerateTime(struct ArgusModelerStruct *);
 void setArgusGenerateTime(struct ArgusModelerStruct *, int);
 int getArgusGeneratePacketSize(struct ArgusModelerStruct *);
 void setArgusGeneratePacketSize(struct ArgusModelerStruct *, int);
+int getArgusGeneratePacketSizeHisto(struct ArgusModelerStruct *);
+void setArgusGeneratePacketSizeHisto(struct ArgusModelerStruct *, int);
 void setArgusTimeReport(struct ArgusModelerStruct *, int);
 
 struct timeval *getArgusQueueInterval(struct ArgusModelerStruct *);
@@ -489,8 +556,6 @@ void ArgusModelerCleanUp (struct ArgusModelerStruct *);
 
 void *ArgusCreateFlow (struct ArgusModelerStruct *, void *, int);
 struct ArgusSystemFlow *ArgusCreateArpFlow (struct ArgusModelerStruct *, struct ether_header *);
-void *ArgusCreateIPv4Flow (struct ArgusModelerStruct *, struct ip *);
-void *ArgusCreateIPv6Flow (struct ArgusModelerStruct *, struct ip6_hdr *);
 struct ArgusSystemFlow *ArgusCreateESPv6Flow (struct ArgusModelerStruct *, struct ip6_hdr *);
 struct ArgusSystemFlow *ArgusCreateESPFlow (struct ArgusModelerStruct *, struct ip *);
 struct ArgusSystemFlow *ArgusCreateLcpFlow (struct ArgusModelerStruct *, struct lcp_hdr *);
@@ -512,6 +577,8 @@ struct ArgusFlowStruct *ArgusFindFlow (struct ArgusModelerStruct *, struct Argus
 
 void ArgusICMPMappedFlowRecord (struct ArgusFlowStruct *, struct ArgusRecord *, unsigned char);
 
+int ArgusFlowPacketDuplicate (struct ArgusModelerStruct *, struct ArgusFlowStruct *);
+
 struct ArgusFlowStruct *ArgusUpdateState (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char, unsigned char);
 struct ArgusFlowStruct *ArgusUpdateFlow (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char, unsigned char);
 void ArgusUpdateAppState (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char);
@@ -557,6 +624,7 @@ void setArgusArpTimeout(struct ArgusModelerStruct *, int);
 int getArgusOtherTimeout(struct ArgusModelerStruct *);
 void setArgusOtherTimeout(struct ArgusModelerStruct *, int);
 
+int getArgusHashTableSize (struct ArgusModelerStruct *);
 
 unsigned int getArgusLocalNet(struct ArgusModelerStruct *);
 void setArgusLocalNet(struct ArgusModelerStruct *, unsigned int);
@@ -564,6 +632,8 @@ void setArgusLocalNet(struct ArgusModelerStruct *, unsigned int);
 unsigned int getArgusNetMask(struct ArgusModelerStruct *);
 void setArgusNetMask(struct ArgusModelerStruct *, unsigned int);
 
+void setArgusEncapsCapture (struct ArgusModelerStruct *model, char *);
+int getArgusEncapsCapture (struct ArgusModelerStruct *model);
 
 void ArgusSystemTimeout (struct ArgusModelerStruct *);
  
@@ -582,10 +652,28 @@ extern  int ArgusUpdateFRAGState (struct ArgusModelerStruct *, struct ArgusFlowS
 extern void ArgusUpdateESPState (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char *);
 
 
+extern unsigned short ArgusParseVxLan (struct ArgusModelerStruct *, void *);
+extern unsigned short ArgusParseGeneve (struct ArgusModelerStruct *, void *);
+extern unsigned short ArgusParseL2TP  (struct ArgusModelerStruct *, void *);
+
+
+struct ArgusTransportRoutines
+RaPortAlgorithmTable[MAX_PORT_ALG_TYPES] = {
+#define ARGUS_PARSE_L2TP	0
+   { "l2tp",  ARGUS_L2TP_PROTO, ARGUS_PARSE_L2TP,  1701, ArgusParseL2TP},
+#define ARGUS_PARSE_VXLAN	1
+   { "vxlan", ARGUS_VXLAN_PROTO, ARGUS_PARSE_VXLAN, 4789, ArgusParseVxLan},
+   { "vxlan", ARGUS_VXLAN_PROTO, ARGUS_PARSE_VXLAN, 8472, ArgusParseVxLan},
+#define ARGUS_PARSE_GENEVE	2
+   { "geneve", ARGUS_GENEVE_PROTO, ARGUS_PARSE_GENEVE, 6081, ArgusParseGeneve},
+};
+
+
 #else /* #if defined(ArgusModeler) */
 
 extern struct ArgusModelerStruct *ArgusModel;
-extern struct llc ArgusThisLLCBuffer;
+extern struct argus_llc ArgusThisLLCBuffer;
+extern struct ArgusTransportRoutines RaPortAlgorithmTable[];
 
 #if defined(LBL_ALIGN)
 extern unsigned char *ArgusAlignBuf;
@@ -595,6 +683,9 @@ extern unsigned char *ArgusAlignBuf;
 void clearArgusConfiguration (struct ArgusModelerStruct *);
 #endif
 
+typedef unsigned short (*pproc)(void *ptr);
+extern pproc ArgusTransportParseRoutines [];
+
 extern struct ArgusModelerStruct *ArgusNewModeler(void);
 extern struct ArgusModelerStruct *ArgusCloneModeler(struct ArgusModelerStruct *);
 
@@ -626,12 +717,24 @@ extern void setArgusFragTimeout (struct ArgusModelerStruct *model, int value);
 extern void setArgusArpTimeout (struct ArgusModelerStruct *model, int value);
 extern void setArgusOtherTimeout (struct ArgusModelerStruct *model, int value);
 
+extern int getArgusHashTableSize (struct ArgusModelerStruct *model);
+
 extern void setArgusSynchronize (struct ArgusModelerStruct *, int);
 
 extern int getArgusKeystroke(struct ArgusModelerStruct *);
 extern void setArgusKeystroke(struct ArgusModelerStruct *, int);
 extern void setArgusKeystrokeVariable(struct ArgusModelerStruct *, char *);
 
+extern int getArgusOSFingerPrinting (struct ArgusModelerStruct *);
+extern void setArgusOSFingerPrinting (struct ArgusModelerStruct *, int);
+
+extern void setArgusPacketCaptureProtocols(struct ArgusDumpStruct *, char *);
+extern void setArgusControlPlaneProtocols(struct ArgusModelerStruct *, char *);
+
+extern void setArgusEncapsCapture (struct ArgusModelerStruct *model, char *);
+extern int getArgusEncapsCapture (struct ArgusModelerStruct *model);
+
+
 extern int getArgusTunnelDiscovery(struct ArgusModelerStruct *);
 extern void setArgusTunnelDiscovery(struct ArgusModelerStruct *, int);
 
@@ -647,6 +750,8 @@ extern int getArgusAflag(struct ArgusModelerStruct *);
 extern void setArgusAflag(struct ArgusModelerStruct *, int);
 extern int getArgusTCPflag(struct ArgusModelerStruct *);
 extern void setArgusTCPflag(struct ArgusModelerStruct *, int);
+extern int getArgusHashflag(struct ArgusModelerStruct *);
+extern void setArgusHashflag(struct ArgusModelerStruct *, int);
 extern int getArgusmflag(struct ArgusModelerStruct *);
 extern void setArgusmflag(struct ArgusModelerStruct *, int);
 extern int getArgusUserDataLen(struct ArgusModelerStruct *);
@@ -668,6 +773,8 @@ extern void setArgusGenerateTime(struct ArgusModelerStruct *, int);
 
 extern int getArgusGeneratePacketSize(struct ArgusModelerStruct *);
 extern void setArgusGeneratePacketSize(struct ArgusModelerStruct *, int);
+extern int getArgusGeneratePacketSizeHisto(struct ArgusModelerStruct *);
+extern void setArgusGeneratePacketSizeHisto(struct ArgusModelerStruct *, int);
 
 extern void setArgusTimeReport(struct ArgusModelerStruct *, int);
 
@@ -707,6 +814,8 @@ extern int ArgusCreateFlowKey (struct ArgusModelerStruct *, struct ArgusSystemFl
 
 extern void ArgusICMPMappedFlowRecord (struct ArgusFlowStruct *, struct ArgusRecord *, unsigned char);
 
+extern int ArgusFlowPacketDuplicate (struct ArgusModelerStruct *, struct ArgusFlowStruct *);
+
 extern struct ArgusFlowStruct *ArgusUpdateState (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char, unsigned char);
 extern struct ArgusFlowStruct *ArgusUpdateFlow (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char, unsigned char);
 extern void ArgusUpdateAppState (struct ArgusModelerStruct *, struct ArgusFlowStruct *, unsigned char);
@@ -731,6 +840,9 @@ extern void setArgusStatusReportInterval(struct ArgusModelerStruct *, int);
 extern int getArgusResponseStatus(struct ArgusModelerStruct *);
 extern void setArgusResponseStatus(struct ArgusModelerStruct *, int value);
 
+extern int getArgusHashTableSize (struct ArgusModelerStruct *model);
+extern void setArgusHashTableSize (struct ArgusModelerStruct *model, int value);
+
 extern int getArgusIPTimeout(struct ArgusModelerStruct *);
 extern void setArgusIPTimeout(struct ArgusModelerStruct *, int);
 
