@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Argus files - Fragment processing
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Netflow processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/argus/argus/argus/ArgusNetflow.c#23 $
+ * $DateTime: 2011/01/26 17:21:20 $
+ * $Change: 2089 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -326,18 +336,18 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -511,18 +521,18 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -690,18 +700,18 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -869,18 +879,18 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -908,7 +918,7 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
 
                case CISCO_VERSION_9: {
                   CiscoFlowEntryV9_t *ArgusNetFlow = (CiscoFlowEntryV9_t *) ptr;
-                  int done = 0, flowset_id, flowset_len;
+                  int flowset_id, flowset_len;
 
                   flowset_id  = ntohs(ArgusNetFlow->flowset_id);
                   if ((flowset_len = ntohs(ArgusNetFlow->length)) > 0) {
@@ -935,8 +945,7 @@ ArgusParseCiscoRecord (struct ArgusModelerStruct *model, void *ptr)
                      ptr += flowset_len;
                      break;
 
-                  } else
-                     done++;
+                  }
                }
             }
             break;
