@@ -1,24 +1,36 @@
 /*
- * Argus Software.  Argus files - Output include file
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Output include files
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/*
+ * $Id: //depot/gargoyle/argus/argus/ArgusOutput.h#7 $
+ * $DateTime: 2015/04/21 19:24:29 $
+ * $Change: 3018 $
+ */
+
+
 
 #ifndef ArgusOutput_h
 #define ArgusOutput_h
@@ -97,6 +109,13 @@ struct ArgusBindAddrStruct {
 
 
 struct ArgusOutputStruct {
+   int type, status;
+ 
+#if defined(ARGUS_THREADS)
+   pthread_t thread;
+   pthread_mutex_t lock;
+#endif
+
    struct ArgusSourceStruct *ArgusSrc;
    struct ArgusModelerStruct *ArgusModel;
    struct ArgusListStruct *ArgusWfileList;
@@ -110,13 +129,6 @@ struct ArgusOutputStruct {
 
    long long ArgusTotalRecords, ArgusLastRecords;
 
-   int status;
-
-#if defined(ARGUS_THREADS)
-   pthread_t thread;
-   pthread_mutex_t lock;
-#endif
-
    int ArgusWriteStdOut;
    int ArgusOutputSequence;
 
@@ -135,6 +147,9 @@ struct ArgusOutputStruct {
    struct timeval ArgusReportTime;
    struct timeval ArgusLastMarUpdateTime;
    struct timeval ArgusMarReportInterval;
+   struct timeval ArgusMarInfTime;
+   struct timeval ArgusLastMarInfUpdateTime;
+   struct timeval ArgusMarInfReportInterval;
 };
 
 struct ArgusWfileStruct {
@@ -157,7 +172,6 @@ void ArgusInitOutputProcess(void);
 
 void *ArgusOutputProcess(void *);
 
-int ArgusEstablishListen (struct ArgusOutputStruct *, char *);
 int  ArgusTcpWrapper (int, struct sockaddr *);
 
 void ArgusUsr1Sig (int);
@@ -167,6 +181,16 @@ void ArgusChildExit (int);
 void ArgusClientError(void);
 void ArgusInitClientProcess(struct ArgusClientData *, struct ArgusWfileStruct *);
 
+struct ArgusRecordStruct *ArgusGenerateSupplementalMarRecord (struct ArgusOutputStruct *, unsigned char);
+
+int ArgusOutputMarInfTime(struct ArgusOutputStruct *);
+
+struct timeval *getArgusMarReportInterval(struct ArgusOutputStruct *);
+void setArgusMarReportInterval(struct ArgusOutputStruct *, char *);
+
+struct timeval *getArgusMarInfReportInterval(struct ArgusOutputStruct *);
+void setArgusMarInfReportInterval(struct ArgusOutputStruct *, char *);
+
 #if defined(ARGUS_TILERA)
 #else
 extern char *ArgusFilterCompile(struct nff_program *, char *, int);
@@ -212,8 +236,10 @@ extern void setArgusWfile(char *, char *);
 extern struct timeval *getArgusMarReportInterval(struct ArgusOutputStruct *);
 extern void setArgusMarReportInterval(struct ArgusOutputStruct *, char *);
 
+extern struct timeval *getArgusMarInfReportInterval(struct ArgusOutputStruct *);
+extern void setArgusMarInfReportInterval(struct ArgusOutputStruct *, char *);
+
 extern void ArgusCheckClientStatus (struct ArgusOutputStruct *, int);
-extern int ArgusEstablishListen (struct ArgusOutputStruct *, char *);
 extern int  ArgusTcpWrapper (int, struct sockaddr *);
 
 extern void ArgusCloseSocket (int);
