@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Argus files - Fragment processing
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Sflow record processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusSflow.c#5 $
+ * $DateTime: 2016/02/16 17:07:05 $
+ * $Change: 3096 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -293,18 +303,18 @@ ArgusParseSflowRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -480,18 +490,18 @@ ArgusParseSflowRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -667,18 +677,18 @@ ArgusParseSflowRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
@@ -854,18 +864,19 @@ ArgusParseSflowRecord (struct ArgusModelerStruct *model, void *ptr)
                         }
                      }
                      if (model->ArgusThisFlow && (model->ArgusThisFlow->ip_flow.ip_src != 0)) {
-                        struct ArgusTransportStruct *trans = &flow->canon.trans;
-                        trans->hdr.type               = ARGUS_TRANSPORT_DSR;
-                        trans->hdr.subtype            = ARGUS_SRCID | ARGUS_SEQ;
-                        trans->hdr.argus_dsrvl8.qual  = ARGUS_TYPE_IPV4;
-                        trans->hdr.argus_dsrvl8.len   = 3;
-                        trans->srcid.a_un.ipv4        = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
-                                                        model->ArgusThisFlow->ip_flow.ip_dst :
-                                                        model->ArgusThisFlow->ip_flow.ip_src ;
+                        struct ArgusV3TransportStruct *trans = (struct ArgusV3TransportStruct *)&flow->canon.trans;
+                        trans->hdr.type                      = ARGUS_TRANSPORT_DSR;
+                        trans->hdr.subtype                   = ARGUS_SRCID | ARGUS_SEQ;
+                        trans->hdr.argus_dsrvl8.qual         = ARGUS_TYPE_IPV4;
+                        trans->hdr.argus_dsrvl8.len          = 3;
+                        trans->srcid.a_un.ipv4               = (model->ArgusThisFlow->hdr.subtype & ARGUS_REVERSE) ?
+                                                                model->ArgusThisFlow->ip_flow.ip_dst :
+                                                                model->ArgusThisFlow->ip_flow.ip_src ;
+
+                        trans->seqnum                        = ArgusFlowSeq + ArgusCounter++;
+                        flow->dsrindex                      |= 1 << ARGUS_TRANSPORT_INDEX;
+                        flow->dsrs[ARGUS_TRANSPORT_INDEX]    = (void *)trans;
 
-                        trans->seqnum                 = ArgusFlowSeq + ArgusCounter++;
-                        flow->dsrindex |= 1 << ARGUS_TRANSPORT_INDEX;
-                        flow->dsrs[ARGUS_TRANSPORT_INDEX] = (void *)trans;
                      }
                      {
                         struct ArgusIPAttrStruct *attr = &flow->canon.attr;
