@@ -1,24 +1,37 @@
+
 /*
- * Argus Software.  Argus files - Input includes
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Source processor
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/*
+ * $Id: //depot/gargoyle/argus/argus/ArgusSource.h#12 $
+ * $DateTime: 2016/10/03 10:25:27 $
+ * $Change: 3209 $
+ */
+
+/*  ArgusSource.h */
 
 #ifndef ArgusSource_h
 #define ArgusSource_h
@@ -156,12 +169,24 @@ int pcap_offline_read(pcap_t *, int, pcap_handler, u_char *);
 #define ARGUS_TYPE_BOND		0x02
 #define ARGUS_TYPE_DUPLEX	0x04
 
+#define ARGUS_LAUNCHED          0x01
+#define ARGUS_INITED            0x02
+#define ARGUS_COMPLETE          0x04
+#define ARGUS_NOSOURCES         0x08
+#define ARGUS_DONT_OPEN		0x10
+
 struct ArgusDeviceStruct {
    struct ArgusListObjectStruct *nxt;
    int status, type, mode, link, idtype, dlt;
-   struct ArgusAddrStruct ArgusID;
+
+   struct ArgusTransportStruct trans;
+
    char *name, *dltname;
    struct ArgusListStruct *list;
+
+   struct ArgusSourceStruct *src;
+   struct ArgusMarInterfaceStruct *inf;
+
 #if defined(ARGUS_TILERA)
    netio_input_config_t config;
 #endif
@@ -238,11 +263,12 @@ struct arguspcap {
  
 struct ArgusInterfaceStruct {
    struct ArgusDeviceStruct *ArgusDevice;
-   struct ifreq ifr;
+   struct ArgusDumpStruct *ArgusDump;
    pcap_t *ArgusPd;
    struct bpf_program ArgusFilter;
    int state, index, ArgusInterfaceType;
    pcap_handler ArgusCallBack;
+   struct ifreq ifr;
 
    struct arguspcap ArgusPcap;
 
@@ -686,19 +712,53 @@ static int juniper_parse_header (const u_char *, const struct pcap_pkthdr *, str
 
 #define ARGUS_HOLDING	1
 
+struct ArgusDumpStruct {
+   int state, status, proc;
+
+#if defined(ARGUS_THREADS)
+   pthread_t thread;
+   pthread_mutex_t lock;
+   pthread_cond_t cond;
+#endif
+
+   char *ArgusWriteOutPacketFile;
+   pcap_dumper_t *ArgusPcapOutFile;
+   pcap_t *ArgusPd;
+
+   int ArgusDumpPacket;
+   int ArgusDumpPacketOnError;
+   int ArgusDumpPacketOnProtocol;
+
+   unsigned long ArgusPacketOffset;
+
+   char *ppc;
+};
+
 struct ArgusSourceStruct {
    int state, status, proc;
+   int timeStampType;
+
+#if defined(ARGUS_THREADS)
+   pthread_t thread;
+   pthread_mutex_t lock;
+   pthread_cond_t cond;
+#endif
  
    struct ArgusListStruct *ArgusDeviceList;
    struct ArgusListStruct *ArgusRfileList;
    struct ArgusModelerStruct *ArgusModel;
+   struct ArgusDumpStruct *ArgusDump;
  
-   char *ArgusInputFilter;
+   char *ArgusInputFilter, *ArgusDeviceStr;
+   char *ArgusWriteOutPacketFile;
 
-   struct ArgusAddrStruct ArgusID;
-   int ArgusPcapBufSize, type, mode;
+   struct ArgusTransportStruct trans;
+   char * ArgusMarIncludeInterface;
 
-   struct timeval ArgusStartTime, ArgusEndTime, marktime, lasttime;
+   int ArgusPcapBufSize, ArgusPcapDispatchNum, type, mode;
+   int ArgusInterfaceScanInterval;
+
+   struct timeval ArgusStartTime, ArgusEndTime, lasttime;
 
    int ArgusSnapLength, ArgusThisLength;
    unsigned char *ArgusThisSnapEnd;
@@ -718,23 +778,14 @@ struct ArgusSourceStruct {
    struct ArgusInterfaceStruct ArgusInterface[ARGUS_MAXINTERFACE];
    struct ArgusSourceStruct *srcs[ARGUS_MAXINTERFACE];
 
-#if defined(ARGUS_THREADS)
-   pthread_t thread;
-   pthread_mutex_t lock;
-   pthread_cond_t cond;
-#endif
-
 #if defined(ARGUS_TILERA)
   netio_queue_t queue;
 #endif
 
-   int ArgusInputPacketFileType;
    int ArgusReadingOffLine;
-   int Argusbpflag, ArgusCaptureFlag;
-   int Argusfflag, ArgusDumpPacket;
-   int ArgusDumpPacketOnError;
-   unsigned long ArgusPacketOffset;
-  
+   int ArgusInputPacketFileType;
+   int Argusbpflag, ArgusCaptureFlag, Argusfflag;
+
    FILE *ArgusPacketInput;
    long ArgusInputOffset;
  
@@ -742,18 +793,20 @@ struct ArgusSourceStruct {
    char **ArgusArgv;
    int ArgusOptind;
    char *ArgusCmdBuf;
-
-   char *ArgusWriteOutPacketFile;
-   pcap_dumper_t *ArgusPcapOutFile;
 };
 
 
-void ArgusParseSourceID (struct ArgusSourceStruct *, char *);
+int setArgusListInterfaces (struct ArgusSourceStruct *, int);
+int setArgusTimestampType(char *);
+int setArgusDeDup(char *);
+
+void ArgusParseSourceID (struct ArgusSourceStruct *, struct ArgusDeviceStruct *, char *);
+void setArgusManInf (struct ArgusSourceStruct *, char *);
+char *getArgusManInf (struct ArgusSourceStruct *);
 
 int ArgusSnoopRead (struct ArgusSourceStruct *);
 
 void ArgusIpPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
-void ArgusPflogPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusArcnetPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusEtherPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusTokenPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
@@ -777,6 +830,7 @@ void ArgusEncPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p)
 void ArgusDagPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusJuniperPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusIpNetPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
+void ArgusPflogPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 void ArgusNullPacket (u_char *user, const struct pcap_pkthdr *h, const u_char *p);
 
 
@@ -800,15 +854,15 @@ void Argusbpf_dump(struct bpf_program *, int);
 void setArgusRealTime (struct ArgusSourceStruct *, float value);
 float getArgusRealTime (struct ArgusSourceStruct *);
 
-unsigned int getArgusID(struct ArgusSourceStruct *);
+int getArgusID(struct ArgusSourceStruct *, struct ArgusAddrStruct *);
 unsigned int getArgusIDType(struct ArgusSourceStruct *);
 
-void setArgusID(struct ArgusSourceStruct *src, void *ptr, unsigned int type);
+void setArgusID(struct ArgusSourceStruct *, void *, int, unsigned int);
 
-void setArgusMoatTshFile (struct ArgusSourceStruct *, int value);
+void setArgusMoatTshFile (struct ArgusSourceStruct *, int);
 int getArgusMoatTshFile (struct ArgusSourceStruct *);
 
-void setArgusWriteOutPacketFile (struct ArgusSourceStruct *, char *);
+void setArgusWriteOutPacketFile (struct ArgusDumpStruct *, char *);
 
 
 
@@ -818,7 +872,8 @@ void setArgusInterfaceType(struct ArgusSourceStruct *, unsigned char);
 unsigned char getArgusInterfaceStatus(struct ArgusSourceStruct *);
 void setArgusInterfaceStatus(struct ArgusSourceStruct *, unsigned char);
 
-int setArgusListInterfaces (struct ArgusSourceStruct *, int);
+void setArgusPacketCaptureProtocols(struct ArgusDumpStruct *, char *);
+
 
 #if defined(ArgusSource)
 
@@ -899,6 +954,7 @@ static struct callback ArgusSourceCallbacks[] = {
 extern int Argustflag;
 
 struct ArgusSourceStruct *ArgusSourceTask = NULL;
+struct ArgusDumpStruct *ArgusDumpTask = NULL;
 
 struct ArgusSourceStruct *ArgusNewSource(struct ArgusModelerStruct *);
 struct ArgusSourceStruct *ArgusCloneSource(struct ArgusSourceStruct *);
@@ -906,12 +962,13 @@ int ArgusInitSource(struct ArgusSourceStruct *);
 int ArgusCloseSource(struct ArgusSourceStruct *);
 void ArgusDeleteSource(struct ArgusSourceStruct *);
 
+struct ArgusDumpStruct *ArgusNewDump(struct ArgusSourceStruct *, struct ArgusInterfaceStruct *);
+
 extern char *ArgusCopyArgv (char **argv);
 
 void setArgusOutputTask(void);
 void setArgusModeler(struct ArgusSourceStruct *);
 
- 
 struct ArgusOutputStruct *getArgusOutputTask(void);
 struct ArgusModelerStruct *getArgusModeler(struct ArgusSourceStruct *);
 
@@ -946,6 +1003,7 @@ int ArgusCreatePktFromFddi(const struct fddi_header *, struct ether_header *, in
 #else /* defined(ArgusSource) */
 
 extern struct ArgusSourceStruct *ArgusSourceTask;
+extern struct ArgusDumpStruct *ArgusDumpTask;
 
 extern long long ArgusTotalPkts;
 extern long long ArgusLastPkts;
@@ -954,14 +1012,14 @@ extern long long ArgusLastDrop;
 extern long long ArgusTotalBytes;
 extern long long ArgusLastBytes;
 
-extern struct ArgusSourceStruct *ArgusSourceTask;
-
 extern struct ArgusSourceStruct *ArgusNewSource(struct ArgusModelerStruct *);
 extern struct ArgusSourceStruct *ArgusCloneSource(struct ArgusSourceStruct *);
 extern int ArgusInitSource(struct ArgusSourceStruct *);
 extern int ArgusCloseSource(struct ArgusSourceStruct *);
 extern void ArgusDeleteSource(struct ArgusSourceStruct *);
 
+extern struct ArgusDumpStruct *ArgusNewDump(struct ArgusSourceStruct *, struct ArgusInterfaceStruct *);
+
 extern struct ArgusOutputStruct *getArgusOutputTask(struct ArgusSourceStruct *);
 extern void setArgusOutputTask(struct ArgusSourceStruct *);
 
@@ -984,7 +1042,7 @@ extern void setArgusOflag(struct ArgusSourceStruct *, int);
 extern void setArgusCaptureFlag(struct ArgusSourceStruct *, int);
 extern void setArgusMoatTshFile (struct ArgusSourceStruct *, int value);
 
-extern void setArgusWriteOutPacketFile (struct ArgusSourceStruct *, char *);
+extern void setArgusWriteOutPacketFile (struct ArgusDumpStruct *, char *);
 
 extern void setArgusDevice(struct ArgusSourceStruct *, char *, int, int);
 extern void setArgusInfile(struct ArgusSourceStruct *, char *);
