@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Argus files - TCP protocol
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - TCP Protocol processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusTcp.c#11 $
+ * $DateTime: 2016/09/18 16:32:53 $
+ * $Change: 3186 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -31,6 +41,7 @@
 
 #include <argus_compat.h>
 #include <ArgusModeler.h>
+#include "ArgusTimeDiff.h"
 
 #include <netinet/tcp.h>
 #include <netinet/tcp_fsm.h>
@@ -92,9 +103,11 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
          net->hdr.type             = ARGUS_NETWORK_DSR;
          net->hdr.subtype          = ARGUS_TCP_INIT;
          net->hdr.argus_dsrvl8.len = ((sizeof(struct ArgusTCPInitStatus)+3))/4 + 1;
-         net->hdr.argus_dsrvl8.qual = 0;
+         net->hdr.argus_dsrvl8.qual = ARGUS_TCP_INIT_V2;
+
          flowstr->dsrs[ARGUS_NETWORK_INDEX] = (struct ArgusDSRHeader *) net;
-         tcpExt                    = &net->net_union.tcp;
+
+         tcpExt = &net->net_union.tcp;
          bzero ((char *)tcpExt, sizeof(*tcpExt));
 
          model->ArgusSnapLength -= tcphlen;
@@ -147,7 +160,9 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                      tcpExt->options |= ARGUS_TCP_SRC_ECN;
                   break;
          
-               case (TH_SYN|TH_ACK): {
+               case (TH_SYN|TH_ACK): 
+               case (TH_SYN|TH_ACK|TH_PUSH):
+               case (TH_SYN|TH_ACK|TH_PUSH|TH_URG): {
                   tcpExt->status      |= ARGUS_SAW_SYN_SENT;
                   tcpExt->state        = TCPS_SYN_RECEIVED;
                   ArgusThisTCPsrc->bytes   += model->ArgusThisLength;
@@ -184,6 +199,9 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
       
                case (TH_FIN):
                case (TH_FIN|TH_ACK):
+               case (TH_FIN|TH_ACK|TH_URG):
+               case (TH_FIN|TH_ACK|TH_PUSH):
+               case (TH_FIN|TH_ACK|TH_PUSH|TH_URG):
                   tcpExt->status      |= ARGUS_FIN;
                   tcpExt->state        = TCPS_FIN_WAIT_1;
                   ArgusThisTCPsrc->bytes   += model->ArgusThisLength;
@@ -196,7 +214,7 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
       
                default:
                   tcpExt->status      |= ARGUS_CON_ESTABLISHED;
-                  tcpExt->state        = TCPS_CLOSING;
+                  tcpExt->state        = TCPS_ESTABLISHED;
                   ArgusThisTCPsrc->bytes   += model->ArgusThisLength;
                   ArgusThisTCPsrc->flags   |= flags; 
                   ArgusThisTCPsrc->seqbase  = tcp->th_seq - 1;
@@ -225,19 +243,27 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
          }
 
          switch (tcpExt->state) {
+            case TCPS_CLOSE_WAIT:
+            case TCPS_FIN_WAIT_1:
+            case TCPS_CLOSING:
+            case TCPS_LAST_ACK:
+            case TCPS_FIN_WAIT_2:
+            case TCPS_TIME_WAIT:
             case TCPS_LISTEN: {
                if (flags & TH_SYN) {
                   ArgusSendFlowRecord (model, flowstr, ARGUS_STOP);
-                  ArgusInitializeTCP (model, flowstr);
+                  ArgusZeroRecord (flowstr);
                   ArgusRemoveFromQueue(flowstr->qhdr.queue, &flowstr->qhdr, ARGUS_LOCK);
-                  ArgusPushQueue(model->ArgusStatusQueue, &flowstr->qhdr, ARGUS_LOCK);
 
-                  *state = ARGUS_START;
+                  ArgusInitializeTCP (model, flowstr);
+                  tcpExt->status |= ARGUS_PORT_REUSE;
+
+                  ArgusPushQueue(model->ArgusStatusQueue, &flowstr->qhdr, ARGUS_LOCK);
+                  return;
+                  
 //                ArgusUpdateBasicFlow (model, flowstr, ARGUS_START);
 //                ArgusUpdateTCPState (model, flowstr, state);
                }
-               ArgusThisTCPsrc->flags   |= flags;
-               break;
             }
 
             default: {
@@ -283,7 +309,7 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                            return;
                         }
                         break;
-   
+
                      case TCPS_CLOSED:
                      case TCPS_TIME_WAIT:
                         if (!(tcpExt->status & ARGUS_RESET))
@@ -292,9 +318,10 @@ ArgusUpdateTCPState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                         break;
                   }
                }
+   
+               ArgusThisTCPsrc->lasttime.tv_sec  = model->ArgusGlobalTime.tv_sec;
+               ArgusThisTCPsrc->lasttime.tv_usec = model->ArgusGlobalTime.tv_usec;
             }
-            ArgusThisTCPsrc->lasttime.tv_sec  = model->ArgusGlobalTime.tv_sec;
-            ArgusThisTCPsrc->lasttime.tv_usec = model->ArgusGlobalTime.tv_usec;
          }
       }
    }
@@ -318,7 +345,6 @@ ArgusInitializeTCP (struct ArgusModelerStruct *model, struct ArgusFlowStruct *fl
    model->ArgusThisDir = 1;
 
    flow->qhdr.lasttime = model->ArgusGlobalTime;
-
    ArgusUpdateFlow (model, flow, ARGUS_START, 0);
 }
 
@@ -327,7 +353,7 @@ int
 ArgusUpdateTCPStateMachine (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flowstr, struct tcphdr *tcp)
 {
    struct ArgusTCPObjectMetrics *ArgusThisTCPsrc, *ArgusThisTCPdst;
-   unsigned char flags = tcp->th_flags;
+   unsigned char flags = tcp->th_flags & (TH_SYN | TH_ACK | TH_RST | TH_FIN) ;
    struct ArgusTCPObject *tcpExt = (struct ArgusTCPObject *)&flowstr->canon.net.net_union.tcp;
    unsigned int state = tcpExt->state;
    int len = model->ArgusThisLength;
@@ -382,6 +408,10 @@ ArgusUpdateTCPStateMachine (struct ArgusModelerStruct *model, struct ArgusFlowSt
                      lasttime.tv_usec = ArgusThisTCPdst->lasttime.tv_usec;
 
                      tcpExt->synAckuSecs = ArgusAbsTimeDiff (&model->ArgusGlobalTime, &lasttime);
+#if defined(ARGUS_NANOSECONDS)
+                     /* convert this from ns to us */
+                     tcpExt->synAckuSecs /= 1000;
+#endif
                   }
                }
 
@@ -422,6 +452,10 @@ ArgusUpdateTCPStateMachine (struct ArgusModelerStruct *model, struct ArgusFlowSt
                      lasttime.tv_usec = ArgusThisTCPdst->lasttime.tv_usec;
 
                      tcpExt->ackDatauSecs = ArgusAbsTimeDiff (&model->ArgusGlobalTime, &lasttime);
+#if defined(ARGUS_NANOSECONDS)
+                     /* convert this from ns to us */
+                     tcpExt->ackDatauSecs /= 1000;
+#endif
                   }
                }
 
@@ -587,10 +621,9 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
          ArgusThisTCPsrc->seqbase = seq;
          ArgusThisTCPsrc->seq = newseq;
       } else {
-
          if (len) {
             if (model->ArgusTrackDuplicates && (tipid && ((ipid != 0) && (*tipid == ipid)))) {
-               if (model->ArgusThisDir) 
+               if (model->ArgusThisDir)
                   ArgusThisTCPsrc->status |= ARGUS_SRC_DUPLICATES;
                else
                   ArgusThisTCPdst->status |= ARGUS_DST_DUPLICATES;
@@ -654,7 +687,7 @@ ArgusUpdateTCPSequence (struct ArgusModelerStruct *model, struct ArgusFlowStruct
       if (tcp->th_ack && (flags & TH_ACK)) {
          if (ArgusThisTCPsrc->ack) {
             if (ArgusThisTCPdst->seq > ArgusThisTCPsrc->ack)
-               ArgusThisTCPdst->winbytes = (ArgusThisTCPdst->seq - 1) - ArgusThisTCPsrc->ack;  
+               ArgusThisTCPdst->winbytes = (ArgusThisTCPdst->seq - 1) - ArgusThisTCPsrc->ack;
          }
 
          if (!(ArgusThisTCPsrc->ack == (tcp->th_ack - 1))) {
@@ -706,13 +739,13 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
 
       if (++flowstr->skey.n_pkts < ArgusKeyStroke->n_min) {
 #ifdef ARGUSDEBUG
-         ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld flow_n_pkts(%d) < n_min(%d)\n", 
+         ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld flow_n_pkts(%d) < n_min(%d)\n", 
             flowstr, model->ArgusTotalPacket, flowstr->skey.n_pkts, ArgusKeyStroke->n_min);
 #endif
          return;
       } else {
 #ifdef ARGUSDEBUG
-         ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld flow_n_pkts(%d)\n", 
+         ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld flow_n_pkts(%d)\n", 
             flowstr, model->ArgusTotalPacket, flowstr->skey.n_pkts);
 #endif
       }
@@ -734,7 +767,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
             if (tcpdatalen % 4) {
                flowstr->status &= ~ARGUS_SSH_MONITOR;
 #ifdef ARGUSDEBUG
-               ArgusDebug (7, "ArgusTCPKeystroke: packet %lld flow %p ssh monitor and tcpdatalen(%d) not mod 4\n", flowstr->skey.n_pkts, flowstr, tcpdatalen);
+               ArgusDebug (5, "ArgusTCPKeystroke: packet %lld flow %p ssh monitor and tcpdatalen(%d) not mod 4\n", flowstr->skey.n_pkts, flowstr, tcpdatalen);
 #endif
                return;
             }
@@ -753,7 +786,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                if ((tcpdatalen >= ArgusKeyStroke->dc_min) && (tcpdatalen <= ArgusKeyStroke->dc_max)) {
                   int i = 0, found = 0;
 #ifdef ARGUSDEBUG
-                  ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld client packet seq(%u) size(%d) OK\n", flowstr, flowstr->skey.n_pkts, tcp->th_seq, tcpdatalen);
+                  ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld client packet seq(%u) size(%d) OK\n", flowstr, flowstr->skey.n_pkts, tcp->th_seq, tcpdatalen);
 #endif
                   for (i = 0; i < ARGUS_NUM_KEYSTROKE_PKTS && !found; i++) {
                      struct ArgusKeyStrokePacket *pkt = &flowstr->skey.data.pkts[i];
@@ -781,7 +814,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                      }
                      if (npkt < 0) {  // nothing but tentatives, so lets clear the tentative at index = 0
 #ifdef ARGUSDEBUG
-                        ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld no non-tentative packets to reject, clearing first\n", flowstr, flowstr->skey.n_pkts);
+                        ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld no non-tentative packets to reject, clearing first\n", flowstr, flowstr->skey.n_pkts);
 #endif
                         npkt = 0;
                      }
@@ -789,7 +822,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                         struct ArgusKeyStrokePacket *pkt = &flowstr->skey.data.pkts[npkt];
                         struct timeval tvpbuf, *tvp = &tvpbuf;
 #ifdef ARGUSDEBUG
-                        ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld clearing client %d seq(%u)\n", flowstr, flowstr->skey.n_pkts, npkt, pkt->seq);
+                        ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld clearing client %d seq(%u)\n", flowstr, flowstr->skey.n_pkts, npkt, pkt->seq);
 #endif
                         pkt->ts.tv_sec  = model->ArgusGlobalTime.tv_sec;
                         pkt->ts.tv_usec = model->ArgusGlobalTime.tv_usec;
@@ -802,7 +835,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                }
 #ifdef ARGUSDEBUG
                  else {
-                  ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld client packet size(%d) NOK reset\n", flowstr, flowstr->skey.n_pkts, tcpdatalen);
+                  ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld client packet size(%d) NOK reset\n", flowstr, flowstr->skey.n_pkts, tcpdatalen);
                }
 #endif
                break;
@@ -836,14 +869,14 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                               if ((pkt->n_pno - flowstr->skey.prev_pno) <= ArgusKeyStroke->gpc_max) {
                                  int i;
 #ifdef ARGUSDEBUG
-                                 ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld server keystroke ", flowstr, flowstr->skey.n_pkts);
+                                 ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld server keystroke ", flowstr, flowstr->skey.n_pkts);
 #endif
                                  flowstr->skey.n_strokes++;
                                  for (i = 0; i < ARGUS_NUM_KEYSTROKE_PKTS; i++) {
                                     struct ArgusKeyStrokePacket *tpkt = &flowstr->skey.data.pkts[i];
                                     if (tpkt->status == ARGUS_KEYSTROKE_TENTATIVE) {
 #ifdef ARGUSDEBUG
-                                       ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld TENTATIVE packet %lld keystroke ", flowstr, flowstr->skey.n_pkts, tpkt->n_pno);
+                                       ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld TENTATIVE packet %lld keystroke ", flowstr, flowstr->skey.n_pkts, tpkt->n_pno);
 #endif
                                        flowstr->skey.n_strokes++;
                                        bzero(tpkt, sizeof(*tpkt));
@@ -862,7 +895,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                                  }
                                  pkt->status = ARGUS_KEYSTROKE_TENTATIVE;
 #ifdef ARGUSDEBUG
-                                 ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld server packet pc_gap(%d) > gpc_max(%d) TENTATIVE\n", 
+                                 ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld server packet pc_gap(%d) > gpc_max(%d) TENTATIVE\n", 
                                        flowstr, flowstr->skey.n_pkts, (pkt->n_pno - flowstr->skey.prev_pno) , ArgusKeyStroke->gpc_max);
 #endif
                                  flowstr->skey.prev_pno  = pkt->n_pno;
@@ -874,27 +907,27 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                            } 
 #ifdef ARGUSDEBUG
                            else {
-                                 ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld server ic_ratio(%f) out of range\n", 
+                                 ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld server ic_ratio(%f) out of range\n", 
                                     flowstr, flowstr->skey.n_pkts, ic_ratio);
                            }
 #endif
                         } 
 #ifdef ARGUSDEBUG
                         else {
-                           ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld rejected server IPA(%lld) < ic_min(%d)\n", 
+                           ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld rejected server IPA(%lld) < ic_min(%d)\n", 
                                     flowstr, flowstr->skey.n_pkts, pkt->intpkt, ArgusKeyStroke->ic_min);
                         }
 #endif
                      } 
 #ifdef ARGUSDEBUG
                      else {
-                        ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld rejected server packet size(%d)\n", flowstr, flowstr->skey.n_pkts, tcpdatalen);
+                        ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld rejected server packet size(%d)\n", flowstr, flowstr->skey.n_pkts, tcpdatalen);
                      }
 #endif
                   } 
 #ifdef ARGUSDEBUG
                   else {
-                     ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld rejected server packet flow s_gap(%d) > gs_gap(%d)\n", 
+                     ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld rejected server packet flow s_gap(%d) > gs_gap(%d)\n", 
                            flowstr, flowstr->skey.n_pkts, (flowstr->skey.n_pkts - pkt->n_pno), ArgusKeyStroke->gs_max);
                   }
 #endif
@@ -909,7 +942,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
                } 
 #ifdef ARGUSDEBUG
                else {
-                  ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld server packet ack(%u) no match\n", 
+                  ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld server packet ack(%u) no match\n", 
                      flowstr, flowstr->skey.n_pkts, tcp->th_ack);
                }
 #endif
@@ -919,7 +952,7 @@ ArgusTCPKeystroke (struct ArgusModelerStruct *model, struct ArgusFlowStruct *flo
       } 
 #ifdef ARGUSDEBUG
       else {
-         ArgusDebug (7, "ArgusTCPKeystroke: flow %p packet %lld %s packet rejected tcpdatalen(%d)\n", 
+         ArgusDebug (5, "ArgusTCPKeystroke: flow %p packet %lld %s packet rejected tcpdatalen(%d)\n", 
                flowstr, flowstr->skey.n_pkts, (model->ArgusThisDir ? "server" : "client"), tcpdatalen);
       }
 #endif
@@ -933,10 +966,9 @@ ArgusTCPFlowRecord (struct ArgusNetworkStruct *net, unsigned char state)
 {
    struct ArgusTCPObject *tcp = (struct ArgusTCPObject *)&net->net_union.tcp;
 
-   net->hdr.argus_dsrvl8.qual = 0;
+   net->hdr.argus_dsrvl8.qual = ARGUS_TCP_INIT_V2;
 
    tcp->status &= ~(ARGUS_RESET | ARGUS_PKTS_RETRANS | ARGUS_WINDOW_SHUT | ARGUS_OUTOFORDER | ARGUS_DUPLICATES);
-
    if (tcp->src.status & ARGUS_RESET)
       tcp->status |= ARGUS_SRC_RESET;
    if (tcp->dst.status & ARGUS_RESET)
@@ -1003,6 +1035,7 @@ ArgusParseTCPOptions(struct ArgusModelerStruct *model, struct tcphdr *tcp, int l
                *options |= ARGUS_TCP_MAXSEG;
                datalen = 2;
                LENCHECK(model, datalen);
+               ArgusThisTCPsrc->maxseg = ntohs(*(u_short *)cp);
                break;
 
             case TCPOPT_EOL:
