@@ -1,6 +1,6 @@
 /*
  * Argus Software.  Argus files - Udt protocol processing
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -19,6 +19,12 @@
  *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusUdt.c#7 $
+ * $DateTime: 2015/09/02 16:24:01 $
+ * $Change: 3068 $
+ */
+
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
 #endif
@@ -208,7 +214,7 @@ ArgusUpdateUDToEState (struct ArgusModelerStruct *model, struct ArgusFlowStruct
                      struct udt_control_nak *nak = (void *) (udtc + 1);
                      int num = 0, len = model->ArgusThisLength/4;
                      unsigned int *sptr = &nak->seqnum;
-                     int i, fitem, sseq, eseq, range;
+                     int i, fitem, sseq = 0, eseq = 0, range = 0;
 #ifdef ARGUSDEBUG
                      char buf[256];
                      *buf = '\0';
@@ -456,7 +462,7 @@ ArgusUpdateUDTState (struct ArgusModelerStruct *model, struct ArgusFlowStruct *f
                      struct udt_control_nak *nak = (void *) (udtc + 1);
                      int num = 0, len = model->ArgusThisLength/4;
                      unsigned int *sptr = &nak->seqnum, value;
-                     int i, fitem, sseq, eseq, range;
+                     int i, fitem, sseq = 0, eseq = 0, range = 0;
 #ifdef ARGUSDEBUG
                      char buf[256];
                      *buf = '\0';
