@@ -1,24 +1,36 @@
 /*
- * Argus Software.  Argus files - Utilities
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Utilities
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/ArgusUtil.c#13 $
+ * $DateTime: 2016/06/07 14:21:31 $
+ * $Change: 3159 $
+ */
+
+/* ArgusUtil.c */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -57,40 +69,10 @@
 #include <argus_parser.h>
 
 #include <ArgusModeler.h>
+#include <ArgusEvents.h>
 #include <argus_dscodepoints.h>
 #include <argus_encapsulations.h>
-
-
-long long
-ArgusTimeDiff (struct timeval *start, struct timeval *stop)
-{
-   long long retn, stime, etime;
-
-   stime = (start->tv_sec * 1000000LL) + start->tv_usec;
-   etime = (stop->tv_sec  * 1000000LL) +  stop->tv_usec;
-
-   retn = stime - etime;
-   return (retn);
-}
-
-unsigned long long
-ArgusAbsTimeDiff (struct timeval *start, struct timeval *stop)
-{
-   unsigned long long retn = 0;
-   struct timeval *t1 = start, *t2 = stop;
-
-   if ((stop->tv_sec < start->tv_sec) || ((stop->tv_sec == start->tv_sec) &&
-                                          (stop->tv_usec < start->tv_usec))) {
-      t2 = start;
-      t1 = stop;
-   }
-
-   retn = ((t2->tv_sec * 1000000LL) + t2->tv_usec) - 
-          ((t1->tv_sec * 1000000LL) + t1->tv_usec);
-
-   return (retn);
-}
-
+#include "ArgusTimeDiff.h"
 
 struct ArgusListStruct *
 ArgusNewList ()
@@ -142,8 +124,15 @@ ArgusDeleteList (struct ArgusListStruct *list, int type)
 
              case ARGUS_DEVICE_LIST: {
                 struct ArgusDeviceStruct *device = (struct ArgusDeviceStruct *) retn;
-                if (device->name != NULL)
+                extern void delete_interface(const u_char *);
+
+                if (device->inf != NULL)
+                   ArgusFree(device->inf);
+
+                if (device->name != NULL) {
+                   delete_interface((const u_char *)device->name);
                    free(device->name);
+                }
                 ArgusFree(retn);
                 break;
              }
@@ -153,10 +142,11 @@ ArgusDeleteList (struct ArgusListStruct *list, int type)
                 break;
 
              case ARGUS_EVENT_LIST: {
-                struct ArgusListObjectStruct *lobj = (struct ArgusListObjectStruct *) retn;
-                if (lobj->obj != NULL) {
-                   ArgusFree(lobj);
-                }
+                struct ArgusEventRecordStruct *event = (struct ArgusEventRecordStruct *) retn;
+                if (event->entry != NULL) free(event->entry);
+                if (event->method != NULL) free(event->method);
+                if (event->filename != NULL) free(event->filename);
+
                 ArgusFree(retn);
                 break;
             }
@@ -368,7 +358,7 @@ ArgusDeleteQueue (struct ArgusQueueStruct *queue)
       if (queue->count > 0) 
          ArgusDebug (1, "ArgusDeleteQueue (%p) contains %d items\n", queue, queue->count);
 #endif
-      while ((obj = ArgusPopQueue(queue, ARGUS_LOCK)))
+      while ((obj = ArgusPopQueue(queue, ARGUS_NOLOCK)))
          ArgusFree(obj);
 
       if (queue->array != NULL) {
@@ -456,11 +446,14 @@ ArgusAddToQueue(struct ArgusQueueStruct *queue, struct ArgusQueueHeader *obj, in
             pthread_mutex_unlock(&queue->lock); 
 #endif
          obj->queue = queue;
+         obj->qtime = ArgusModel->ArgusGlobalTime;
 
+/*
          if (ArgusSourceTask->ArgusReadingOffLine)
             obj->qtime = ArgusModel->ArgusGlobalTime;
          else
             gettimeofday(&obj->qtime, 0L);
+*/
          retn = 1;
 
       } else
@@ -650,44 +643,13 @@ ArgusProcessQueue(struct ArgusModelerStruct *model, struct ArgusQueueStruct *que
 #endif
 }
 
-
-int
-ArgusCheckTimeout(struct ArgusModelerStruct *model, struct timeval *ts, struct timeval *timeout)
-{
-   long long diff = 0, tdiff = 0;
-   int retn;
-
-   if (timeout->tv_sec < 0)  // if timeout is set to less that zero, then we never timeout.
-      retn = 0;
-   else {
-      if ((timeout->tv_sec > 0) || (timeout->tv_usec > 0)) {
-         diff  = ArgusTimeDiff (&model->ArgusGlobalTime, ts);
-         tdiff = (timeout->tv_sec * 1000000LL + timeout->tv_usec);
-
-         if (diff >= tdiff)
-            retn = 1;
-         else
-            retn = 0;
-      } else
-         retn = 1;
-   }
-
-#ifdef ARGUSDEBUG
-   ArgusDebug (11, "ArgusCheckTimeout (%p, %d.%06d, %d.%06d) diff %f returning %d\n", model, ts->tv_sec, ts->tv_usec,
-                      timeout->tv_sec, timeout->tv_usec, (diff / 1000000.0), retn);
-#endif
-
-   return (retn);
-}
-
-
-
 void
 ArgusDeleteObject(struct ArgusFlowStruct *obj)
 {
    if (obj) {
       struct ArgusHashTableHeader *htblhdr;
       struct ArgusNetworkStruct *net = NULL;
+      struct ArgusEncapsStruct *encaps = NULL;
       struct ArgusQueueStruct *queue;
 
       if ((queue = obj->qhdr.queue) != NULL) {
@@ -715,6 +677,17 @@ ArgusDeleteObject(struct ArgusFlowStruct *obj)
          }
       }
 
+      if ((encaps = (struct ArgusEncapsStruct *) obj->dsrs[ARGUS_ENCAPS_INDEX]) != NULL) {
+         if (encaps->sbuf != NULL) {
+            ArgusFree(encaps->sbuf);
+            encaps->slen = 0;
+         }
+         if (encaps->dbuf != NULL) {
+            ArgusFree(encaps->dbuf);
+            encaps->dlen = 0;
+         }
+      }
+
       if (obj->dsrs[ARGUS_SRCUSERDATA_INDEX] != NULL) {
          ArgusFree(obj->dsrs[ARGUS_SRCUSERDATA_INDEX]);
          obj->dsrs[ARGUS_SRCUSERDATA_INDEX] = NULL;
@@ -747,69 +720,66 @@ ArgusDeleteObject(struct ArgusFlowStruct *obj)
 int
 ArgusUpdateTime (struct ArgusModelerStruct *model)
 {
-   long long ival = model->ival;
    long long diff;
    int retn = 0;
 
    if (model->ArgusUpdateTimer.tv_sec == 0) 
       model->ArgusUpdateTimer = model->ArgusGlobalTime;
 
-   diff = ArgusTimeDiff(&model->ArgusGlobalTime, &model->ArgusUpdateTimer);
-
-   if (diff >= 0) {
+   if ((diff = ArgusTimeDiff(&model->ArgusUpdateTimer, &model->ArgusGlobalTime)) >= 0) {
       retn = 1;
 
-      if (diff > ival) 
-         model->ArgusUpdateTimer = model->ArgusGlobalTime;
+#ifdef ARGUSDEBUG
+#if defined(ARGUS_NANOSECONDS)
+      ArgusDebug (8, "ArgusUpdateTime (%p) update %d.%09d global time %d.%09d returning %d\n",
+                   model, model->ArgusUpdateTimer.tv_sec, model->ArgusUpdateTimer.tv_usec,
+                   model->ArgusGlobalTime.tv_sec, model->ArgusGlobalTime.tv_usec, retn);
+#else
+      ArgusDebug (8, "ArgusUpdateTime (%p) update %d.%06d global time %d.%06d returning %d\n",
+                   model, model->ArgusUpdateTimer.tv_sec, model->ArgusUpdateTimer.tv_usec,
+                   model->ArgusGlobalTime.tv_sec, model->ArgusGlobalTime.tv_usec, retn);
+#endif
+#endif
 
+      model->ArgusUpdateTimer = model->ArgusGlobalTime;
       model->ArgusUpdateTimer.tv_sec  += model->ArgusUpdateInterval.tv_sec;
       model->ArgusUpdateTimer.tv_usec += model->ArgusUpdateInterval.tv_usec;
 
-      while (model->ArgusUpdateTimer.tv_usec >= 1000000) {
+#if defined(ARGUS_NANOSECONDS)
+      if (model->ArgusUpdateTimer.tv_usec >= 1000000000) {
+         model->ArgusUpdateTimer.tv_sec++; 
+         model->ArgusUpdateTimer.tv_usec -= 1000000000;
+         if (model->ArgusUpdateTimer.tv_usec >= 1000000000) {
+            ArgusLog (LOG_ERR, "ArgusUpdateTime: usec still too big %d(using NANO)\n", model->ArgusUpdateTimer.tv_usec);
+         }
+      }
+#else
+      if (model->ArgusUpdateTimer.tv_usec >= 1000000) {
          model->ArgusUpdateTimer.tv_sec++; 
          model->ArgusUpdateTimer.tv_usec -= 1000000;
+         if (model->ArgusUpdateTimer.tv_usec >= 1000000) {
+            ArgusLog (LOG_ERR, "ArgusUpdateTime: usec still too big %d(using MICRO)\n", model->ArgusUpdateTimer.tv_usec);
+         }
       }
+#endif
 
    } else {
 
-      if (ArgusSourceTask != NULL) {
-         if (!(ArgusSourceTask->ArgusReadingOffLine)) {
-            if (llabs(diff) > (ival * 2)) {
-
-// something is wrong, so try to figure out if ArgusGlobalTime needs to be adjusted.
-// Must be kernel time bug, so try to reset the ArgusUpdateTimer, and declare
-// that the timer has popped.  Redefine global timer if needed.
-
-               unsigned long long tdiff;
-               struct timeval now;
-
-               retn = 1;
-
-               gettimeofday(&now, 0L);
-               tdiff =  ArgusAbsTimeDiff(&now, &model->ArgusGlobalTime);
-
-               if (tdiff > (ival * 2))
-                  model->ArgusGlobalTime = now;
-
-               model->ArgusUpdateTimer = model->ArgusGlobalTime;
-
-               model->ArgusUpdateTimer.tv_sec  += model->ArgusUpdateInterval.tv_sec;
-               model->ArgusUpdateTimer.tv_usec += model->ArgusUpdateInterval.tv_usec;
-
-               while (model->ArgusUpdateTimer.tv_usec >= 1000000) {
-                  model->ArgusUpdateTimer.tv_sec++;
-                  model->ArgusUpdateTimer.tv_usec -= 1000000;
-               }
-            }
-         }
-      }
+#ifdef ARGUSDEBUG
+#if defined(ARGUS_NANOSECONDS)
+      ArgusDebug (8, "ArgusUpdateTime (%p) update %d.%09d global time %d.%09d returning %d\n",
+                   model, model->ArgusUpdateTimer.tv_sec, model->ArgusUpdateTimer.tv_usec,
+                   model->ArgusGlobalTime.tv_sec, model->ArgusGlobalTime.tv_usec, retn);
+#else
+      ArgusDebug (8, "ArgusUpdateTime (%p) update %d.%06d global time %d.%06d returning %d\n",
+                   model, model->ArgusUpdateTimer.tv_sec, model->ArgusUpdateTimer.tv_usec,
+                   model->ArgusGlobalTime.tv_sec, model->ArgusGlobalTime.tv_usec, retn);
+#endif
+#endif
    }
 
 #ifdef ARGUSDEBUG
-   if (retn) {
-      ArgusDebug (8, "ArgusUpdateTime (%p) global time %d.%06d update %d.%06d returning %d\n",
-                   model, model->ArgusGlobalTime.tv_sec, model->ArgusGlobalTime.tv_usec,
-                   model->ArgusUpdateTimer.tv_sec, model->ArgusUpdateTimer.tv_usec, retn);
+   if (retn > 0) {
    } else
       ArgusDebug (8, "ArgusUpdateTime (%p) not time\n", model);
 #endif
@@ -835,9 +805,10 @@ ArgusNewHashTable (size_t size, int status)
    if ((retn = (struct ArgusHashTable *) ArgusCalloc (1, sizeof(*retn))) == NULL)
       ArgusLog (LOG_ERR, "ArgusNewHashTable: ArgusCalloc(1, %d) error %s\n", size, strerror(errno));
 
-   if ((retn->array = (struct ArgusHashTableHeader **) ArgusCalloc (size, 
-                                      sizeof (struct ArgusHashTableHeader *))) == NULL)
+   if ((retn->array = (struct ArgusHashTableHeader **)
+                      ArgusMallocAligned (size * sizeof(struct ArgusHashTableHeader *), 64)) == NULL)
       ArgusLog (LOG_ERR, "RaMergeQueue: ArgusCalloc error %s\n", strerror(errno));
+   memset(retn->array, 0, size * sizeof (struct ArgusHashTableHeader *));
 
    retn->size = size;
 #if defined(ARGUS_HASH_DEBUG)
@@ -966,8 +937,12 @@ ArgusCreateFlowKey (struct ArgusModelerStruct *model, struct ArgusSystemFlow *fl
 
       hstruct->hash ^= hstruct->hash >> 16;
       hstruct->hash ^= hstruct->hash >> 8;
+      hstruct->ind = hstruct->hash % (model->ArgusHashTableSize - 1);
    }
 
+#ifdef ARGUSDEBUG
+// ArgusDebug (8, "ArgusCreateFlowKey () generated 0x%x hash\n", retn);
+#endif
    return (retn);
 }
 
@@ -981,9 +956,9 @@ ArgusFindFlow (struct ArgusModelerStruct *model, struct ArgusHashStruct *hstruct
 
    if (table && hstruct) {
       unsigned int hash = hstruct->hash;
-      unsigned int ind = (hash % (table->size - 1)), i;
+      unsigned int i;
 
-      if ((target = table->array[ind]) != NULL) {
+      if ((target = table->array[hstruct->ind]) != NULL) {
          unsigned int *ptr3 = hstruct->key;
          int len = hstruct->len;
          head = target;
@@ -1012,7 +987,7 @@ ArgusFindFlow (struct ArgusModelerStruct *model, struct ArgusHashStruct *hstruct
     
          if (hashEntry != NULL) {
             if (hashEntry != head)
-               table->array[ind] = hashEntry;
+               table->array[hstruct->ind] = hashEntry;
             retn = hashEntry->object;
          }
       }
@@ -1025,7 +1000,6 @@ ArgusFindFlow (struct ArgusModelerStruct *model, struct ArgusHashStruct *hstruct
    return (retn);
 }
 
-#define ARGUS_HASH_DEBUG	1
 
 struct ArgusHashTableHeader *
 ArgusAddHashEntry (struct ArgusHashTable *table, struct ArgusFlowStruct *flow, struct ArgusHashStruct *hstruct)
@@ -1033,15 +1007,12 @@ ArgusAddHashEntry (struct ArgusHashTable *table, struct ArgusFlowStruct *flow, s
    struct ArgusHashTableHeader *retn = NULL, *start = NULL;
 
    if (table != NULL) {
-      unsigned int hash = hstruct->hash;
-      int ind;
+      unsigned int ind = hstruct->ind;
 
       retn = &flow->htblbuf;
       memcpy(&retn->hstruct, hstruct, sizeof(*hstruct));
       retn->object = flow;
 
-      ind = (hash % (table->size - 1));
-      
       if ((start = table->array[ind]) != NULL) {
          retn->nxt = start;
          retn->prv = start->prv;
@@ -1080,11 +1051,10 @@ void
 ArgusRemoveHashEntry (struct ArgusHashTableHeader *htblhdr)
 {
    if (htblhdr != NULL) {
-      unsigned int hash = htblhdr->hstruct.hash;
       struct ArgusHashTable *table = htblhdr->htbl;
 
       if (table != NULL) {
-         int ind = (hash % (table->size - 1));
+         unsigned int ind = htblhdr->hstruct.ind;
 
          htblhdr->prv->nxt = htblhdr->nxt;
          htblhdr->nxt->prv = htblhdr->prv;
@@ -1141,12 +1111,12 @@ ArgusZeroRecord (struct ArgusFlowStruct *flow)
 
             case ARGUS_JITTER_INDEX: {
                struct ArgusJitterStruct *jit = (void *)flow->dsrs[i];
-               bzero ((char *)&jit->act, sizeof(struct ArgusJitterObject));
-               bzero ((char *)&jit->idle, sizeof(struct ArgusJitterObject));
-               jit->act.src.minval  = -1.0;
-               jit->idle.src.minval = -1.0;
-               jit->act.dst.minval  = -1.0;
-               jit->idle.dst.minval = -1.0;
+               bzero ((char *)&jit->src, sizeof(struct ArgusJitterObject));
+               bzero ((char *)&jit->dst, sizeof(struct ArgusJitterObject));
+               jit->src.act.minval  = -1.0;
+               jit->src.idle.minval = -1.0;
+               jit->dst.act.minval  = -1.0;
+               jit->dst.idle.minval = -1.0;
                break;
             }
 
@@ -1193,8 +1163,10 @@ ArgusZeroRecord (struct ArgusFlowStruct *flow)
                            case ARGUS_TCP_STATUS:
                            case ARGUS_TCP_PERF: {
                               struct ArgusTCPObject *tcp = &net->net_union.tcp;
-                              tcp->src.status &= ~(ARGUS_RESET|ARGUS_PKTS_RETRANS|ARGUS_WINDOW_SHUT|ARGUS_OUTOFORDER|ARGUS_ECN_CONGESTED);
-                              tcp->dst.status &= ~(ARGUS_RESET|ARGUS_PKTS_RETRANS|ARGUS_WINDOW_SHUT|ARGUS_OUTOFORDER|ARGUS_ECN_CONGESTED);
+                              unsigned int statusMask = ~(ARGUS_PORT_REUSE|ARGUS_RESET|ARGUS_PKTS_RETRANS|ARGUS_WINDOW_SHUT|ARGUS_OUTOFORDER|ARGUS_ECN_CONGESTED);
+                              tcp->src.status &= statusMask;
+                              tcp->dst.status &= statusMask;
+                              tcp->status     &= statusMask;
                               tcp->src.retrans  = 0;
                               tcp->dst.retrans  = 0;
                               tcp->src.flags    = 0;
@@ -1207,6 +1179,7 @@ ArgusZeroRecord (struct ArgusFlowStruct *flow)
                               tcp->dst.ackbytes = 0;
                               tcp->src.seqbase  = tcp->src.seq;
                               tcp->dst.seqbase  = tcp->dst.seq;
+
                               break;
                            }
 
@@ -1361,9 +1334,9 @@ ArgusSetChroot(char *dir)
 #include <fcntl.h>
 
 #define ARGUS_MAXERROR		200000
-#define ARGUS_MAXWRITENUM	10000
+#define ARGUS_MAXWRITENUM	100000
 
-int ArgusMaxListLength = 100000;
+int ArgusMaxListLength = 1000000;
 int ArgusCloseFile = 0;
 
 
@@ -1520,6 +1493,8 @@ ArgusWriteSocket (struct ArgusOutputStruct *output, struct ArgusClientData *clie
                         if (asock->filename != NULL) {
                            close(asock->fd);
                            asock->fd = -1;
+                           if (asock->rec != NULL)
+                              ArgusFreeListRecord(asock->rec);
                            asock->rec = NULL;
                            asock->writen = 0;
                            asock->length = 0;
@@ -2051,8 +2026,13 @@ RaDeltaFloatTime (struct timeval *s1, struct timeval *s2)
    float retn = 0.0;
 
    if (s1 && s2) {
+#if defined(ARGUS_NANOSECONDS)
+      double v1 = (s1->tv_sec * 1.0) + (s1->tv_usec / 1000000000.0);
+      double v2 = (s2->tv_sec * 1.0) + (s2->tv_usec / 1000000000.0);
+#else
       double v1 = (s1->tv_sec * 1.0) + (s1->tv_usec / 1000000.0);
       double v2 = (s2->tv_sec * 1.0) + (s2->tv_usec / 1000000.0);
+#endif
 
       retn = v1 - v2;
    }
@@ -2068,8 +2048,13 @@ RaDiffTime (struct timeval *s1, struct timeval *s2, struct timeval *diff)
    if (s1 && s2 && diff) {
       bzero ((char *)diff, sizeof(*diff));
 
+#if defined(ARGUS_NANOSECONDS)
+      double v1 = (s1->tv_sec * 1.0) + (s1->tv_usec / 1000000000.0);
+      double v2 = (s2->tv_sec * 1.0) + (s2->tv_usec / 1000000000.0);
+#else
       double v1 = (s1->tv_sec * 1.0) + (s1->tv_usec / 1000000.0);
       double v2 = (s2->tv_sec * 1.0) + (s2->tv_usec / 1000000.0);
+#endif
       double f, i;
 
       v1 -= v2;
@@ -2077,7 +2062,11 @@ RaDiffTime (struct timeval *s1, struct timeval *s2, struct timeval *diff)
       f = modf(v1, &i);
 
       diff->tv_sec  = i;
+#if defined(ARGUS_NANOSECONDS)
+      diff->tv_usec = f * 1000000000;
+#else
       diff->tv_usec = f * 1000000;
+#endif
 
       retn = 1;
    }
@@ -2094,13 +2083,23 @@ ArgusDiffTime (struct ArgusTime *s1, struct ArgusTime *s2, struct timeval *diff)
    long long v1 = 0, v2 = 0;
 
    if (s1 && s2 && diff) {
+#if defined(ARGUS_NANOSECONDS)
+      v1 = (s1->tv_sec * 1000000000LL) + s1->tv_usec;
+      v2 = (s2->tv_sec * 1000000000LL) + s2->tv_usec;
+#else
       v1 = (s1->tv_sec * 1000000LL) + s1->tv_usec;
       v2 = (s2->tv_sec * 1000000LL) + s2->tv_usec;
+#endif
 
       v1 -= v2;
 
+#if defined(ARGUS_NANOSECONDS)
+      diff->tv_sec  = v1 / 1000000000;
+      diff->tv_usec = v1 % 1000000000;
+#else
       diff->tv_sec  = v1 / 1000000;
       diff->tv_usec = v1 % 1000000;
+#endif
    }
 
    return (v1);
@@ -2203,7 +2202,11 @@ RaGetFloatDuration (struct ArgusRecordStruct *argus)
       }
    }
 
+#if defined(ARGUS_NANOSECONDS)
+   retn  = (sec * 1.0) + usec/1000000000.0;
+#else
    retn  = (sec * 1.0) + usec/1000000.0;
+#endif
    return (retn);
 }
 
@@ -2223,7 +2226,11 @@ RaGetFloatSrcDuration (struct ArgusRecordStruct *argus)
 
       sec  = ltime->tv_sec  - stime->tv_sec;
       usec = ltime->tv_usec - stime->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+      retn  = (sec * 1.0) + usec/1000000000.0;
+#else
       retn  = (sec * 1.0) + usec/1000000.0;
+#endif
    }
 
    return (retn);
@@ -2245,7 +2252,11 @@ RaGetFloatDstDuration (struct ArgusRecordStruct *argus)
 
       sec  = ltime->tv_sec  - stime->tv_sec;
       usec = ltime->tv_usec - stime->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+      retn  = (sec * 1.0) + usec/1000000000.0;
+#else
       retn  = (sec * 1.0) + usec/1000000.0;
+#endif
    }
 
    return (retn);
@@ -2313,8 +2324,13 @@ ArgusFetchDstLoad (struct ArgusRecordStruct *ns)
    t1d->tv_usec = ns->canon.time.src.end.tv_usec;
 
    t1d->tv_sec  -= ts1->tv_sec; t1d->tv_usec -= ts1->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+   if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000000;}
+   d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000000.0));
+#else
    if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000;}
    d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000.0));
+#endif
  
    if ((m1 = (struct ArgusMetricStruct *) ns->dsrs[ARGUS_METRIC_INDEX]) != NULL)
       cnt1 = m1->dst.pkts; 
@@ -2343,8 +2359,13 @@ ArgusFetchLoad (struct ArgusRecordStruct *ns)
    t1d->tv_usec = ns->canon.time.src.end.tv_usec;
 
    t1d->tv_sec  -= ts1->tv_sec; t1d->tv_usec -= ts1->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+   if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000000;}
+   d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000000.0));
+#else
    if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000;}
    d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000.0));
+#endif
 
    if ((m1 = (struct ArgusMetricStruct *) ns->dsrs[ARGUS_METRIC_INDEX]) != NULL)
       cnt1 = m1->src.pkts + m1->dst.pkts; 
@@ -2671,8 +2692,13 @@ ArgusFetchSrcRate (struct ArgusRecordStruct *ns)
    t1d->tv_usec = ns->canon.time.src.end.tv_usec;
 
    t1d->tv_sec  -= ts1->tv_sec; t1d->tv_usec -= ts1->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+   if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000000;}
+   d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000000.0));
+#else
    if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000;}
    d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000.0));
+#endif
 
    if ((m1 = (struct ArgusMetricStruct *) ns->dsrs[ARGUS_METRIC_INDEX]) != NULL)
       cnt1 = m1->src.bytes * 8;
@@ -2701,8 +2727,13 @@ ArgusFetchDstRate (struct ArgusRecordStruct *ns)
    t1d->tv_usec = ns->canon.time.src.end.tv_usec;
 
    t1d->tv_sec  -= ts1->tv_sec; t1d->tv_usec -= ts1->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+   if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000000;}
+   d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000000.0));
+#else
    if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000;}
    d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000.0));
+#endif
 
    if ((m1 = (struct ArgusMetricStruct *) ns->dsrs[ARGUS_METRIC_INDEX]) != NULL)
       cnt1 = m1->dst.bytes * 8;
@@ -2731,8 +2762,13 @@ ArgusFetchRate (struct ArgusRecordStruct *ns)
    t1d->tv_usec = ns->canon.time.src.end.tv_usec;
 
    t1d->tv_sec  -= ts1->tv_sec; t1d->tv_usec -= ts1->tv_usec;
+#if defined(ARGUS_NANOSECONDS)
+   if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000000;}
+   d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000000.0));
+#else
    if (t1d->tv_usec < 0) {t1d->tv_sec--; t1d->tv_usec += 1000000;}
    d1 = ((t1d->tv_sec * 1.0) + (t1d->tv_usec/1000000.0));
+#endif
 
    if ((m1 = (struct ArgusMetricStruct *) ns->dsrs[ARGUS_METRIC_INDEX]) != NULL)
       cnt1 = (m1->src.bytes + m1->dst.bytes) * 8;
