@@ -1,22 +1,27 @@
 /*
- * Argus Software.  Argus files - Utilities include files
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - Utilities include files
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
 /*
@@ -42,9 +47,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/argus/ArgusUtil.h#33 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/gargoyle/argus/argus/ArgusUtil.h#5 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
  */
 
 
@@ -152,7 +157,6 @@ struct ArgusSocketStruct {
 
 typedef int (*ArgusHandler)(struct ArgusSocketStruct *, unsigned char *, int, void *);
 
-
 #if defined(ArgusUtil)
 
 #if defined(_LITTLE_ENDIAN)
@@ -160,8 +164,6 @@ void ArgusNtoH (struct ArgusRecord *);
 void ArgusHtoN (struct ArgusRecord *);
 #endif
 
-long long ArgusTimeDiff (struct timeval *, struct timeval *);
-unsigned long long ArgusAbsTimeDiff (struct timeval *, struct timeval *);
 
 struct ArgusListStruct *ArgusNewList(void);
 void ArgusDeleteList(struct ArgusListStruct *, int);
@@ -186,8 +188,6 @@ struct ArgusQueueHeader *ArgusPopQueue(struct ArgusQueueStruct *, int);
 struct ArgusQueueHeader *ArgusPopBackQueue (struct ArgusQueueStruct *queue, int type);
 struct ArgusQueueHeader *ArgusRemoveFromQueue(struct ArgusQueueStruct *, struct ArgusQueueHeader *, int);
  
-int ArgusCheckTimeout(struct ArgusModelerStruct *, struct timeval *, struct timeval *);
-
 void ArgusProcessQueue(struct ArgusModelerStruct *, struct ArgusQueueStruct *, int);
 void ArgusEmptyQueue(struct ArgusQueueStruct *);
 
@@ -248,8 +248,6 @@ extern void ArgusNtoH (struct ArgusRecord *);
 extern void ArgusHtoN (struct ArgusRecord *);
 #endif
 
-extern long long ArgusTimeDiff (struct timeval *, struct timeval *);
-extern unsigned long long ArgusAbsTimeDiff (struct timeval *, struct timeval *);
 extern struct ArgusListStruct *ArgusNewList(void);
 extern void ArgusDeleteList(struct ArgusListStruct *, int);
 
@@ -273,8 +271,6 @@ extern struct ArgusQueueHeader *ArgusPopQueue(struct ArgusQueueStruct *, int);
 struct ArgusQueueHeader *ArgusPopBackQueue (struct ArgusQueueStruct *queue, int type);
 extern struct ArgusQueueHeader *ArgusRemoveFromQueue(struct ArgusQueueStruct *, struct ArgusQueueHeader *, int);
 
-extern int ArgusCheckTimeout(struct ArgusModelerStruct *, struct timeval *, struct timeval *);
-
 extern void ArgusProcessQueue(struct ArgusModelerStruct *, struct ArgusQueueStruct *, int);
 extern void ArgusEmptyQueue(struct ArgusQueueStruct *);
 
