@@ -1,24 +1,36 @@
 /*
- * Argus Software.  Argus files - main argus includes
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Argus files - main argus includes
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/argus/argus.h#7 $
+ * $DateTime: 2016/10/04 10:36:36 $
+ * $Change: 3213 $
+ */
+
+
 /*  argus.h */
 
 #include <sys/types.h>
@@ -59,8 +71,9 @@
 #define MAJOR_VERSION_3    3
 #define MAJOR_VERSION_4    4
 #define MAJOR_VERSION_5    5
+#define MAJOR_VERSION_6    6
 
-#define VERSION_MAJOR      MAJOR_VERSION_3
+#define VERSION_MAJOR      MAJOR_VERSION_5
 #define VERSION_MINOR      MINOR_VERSION_0
 
 
@@ -105,10 +118,9 @@ int ArgusMaxSsf = 0;
 int ArgusMinSsf = 0;
 #endif
 
-void ArgusBacktrace (void);
-
 char *ArgusProgramName = NULL;
 void ArgusLoop (void);
+void ArgusBacktrace (void);
 void ArgusScheduleShutDown (int);
 
 void usage(void);
@@ -162,8 +174,6 @@ extern int ArgusMaxSsf;
 extern int ArgusMinSsf;
 #endif
 
-extern void ArgusBacktrace (void);
-
 extern void usage(void);
 extern void ArgusLog (int, char *, ...);
 extern void ArgusComplete (void);
