@@ -1,16 +1,26 @@
 /*
- * Argus Software.  Common library routines - Authentication
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common library routines - Authentication
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * QoSIENT, LLC DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
- * SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
- * AND FITNESS, IN NO EVENT SHALL QoSIENT, LLC BE LIABLE FOR ANY
- * SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
- * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER
- * IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
- * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
- * THIS SOFTWARE.
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Written by Carter Bullard
+ * QoSient, LLC
  *
  */
 
@@ -61,9 +71,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/common/argus_auth.c#13 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/gargoyle/argus/common/argus_auth.c#5 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -478,10 +488,11 @@ RaSaslNegotiate(FILE *in, FILE *out, sasl_conn_t *conn)
 int
 RaSendSaslString (FILE *f, const char *s, int l)
 {
-   char saslbuf[MAXSTRLEN];
+   char *saslbuf;
    int len, al = 0;
 
-   bzero (saslbuf, MAXSTRLEN);
+   if ((saslbuf = ArgusCalloc (1, MAXSTRLEN)) == NULL)
+      ArgusLog (LOG_ERR, "ArgusInitOutput:ArgusCalloc error %s\n", strerror(errno));
    
    snprintf(saslbuf, MAXSTRLEN, "{%d}\r\n", l);
    len = strlen(saslbuf);
@@ -508,6 +519,7 @@ RaSendSaslString (FILE *f, const char *s, int l)
    }
 #endif 
 
+   ArgusFree (saslbuf);
    return al;
 }
 
