@@ -1,22 +1,27 @@
 /*
- * Argus Software
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common library routines - Filter processing
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
-
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
 /*
@@ -60,6 +65,11 @@
  *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/common/argus_filter.c#6 $
+ * $DateTime: 2016/09/18 16:32:53 $
+ * $Change: 3186 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -738,8 +748,7 @@ static inline int skip_space(FILE *);
 static inline int skip_line(FILE *);
 
 static inline int
-skip_space(f)
-FILE *f;
+skip_space(FILE *f)
 {
    int c;
 
@@ -751,8 +760,7 @@ FILE *f;
 }
 
 static inline int
-skip_line(f)
-   FILE *f;
+skip_line(FILE *f)
 {
    int c;
 
@@ -892,8 +900,7 @@ argus_next_etherent(FILE *fp)
  * lowest unit number is preferred; loopback is ignored.
  */
 char *
-ArgusLookupDev(ebuf)
-char *ebuf;
+ArgusLookupDev(char *ebuf)
 {
    int fd, minunit, n;
    char *cp;
@@ -1487,8 +1494,7 @@ compute_local_ud(struct ablock *b)
  * Assume graph is already leveled.
  */
 static void
-find_ud(root)
-   struct ablock *root;
+find_ud(struct ablock *root)
 {
    int i, maxlevel;
    struct ablock *p;
@@ -3130,13 +3136,17 @@ static void
 opt_dump(struct ablock *root)
 {
    struct nff_program f;
-   char buf[MAXSTRLEN];
+   char *buf;
+   char *code = NULL;
+   if ((code = ArgusCalloc (1, MAXSTRLEN)) == NULL)
+      ArgusLog (LOG_ERR, "ArgusInitOutput:ArgusCalloc error %s\n", strerror(errno));
 
    memset(bids, 0, sizeof bids);
    f.bf_insns = Argusicode_to_fcode(root, &f.bf_len);
-   nff_dump(&f, buf, MAXSTRLEN, 1);
-   printf("%s\n", buf);
+   nff_dump(&f, code, MAXSTRLEN, 1);
+   printf("%s\n", code);
    free((char *)f.bf_insns);
+   ArgusFree(code);
 }
 #endif
 
