@@ -1,24 +1,34 @@
 /*
- * Argus Software.  Common library routines - Utilities
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common library routines - Utilities
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- 
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
+/* 
+ * $Id: //depot/gargoyle/argus/common/argus_util.c#13 $
+ * $DateTime: 2016/10/27 18:40:41 $
+ * $Change: 3232 $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "argus_config.h"
@@ -47,9 +57,9 @@
 
 #include <fcntl.h>
 #include <sys/ioctl.h>
-#include <rpc/types.h>
 
 #if defined(HAVE_XDR)
+#include <rpc/types.h>
 #include <rpc/xdr.h>
 #endif
 
@@ -57,6 +67,12 @@
 #include <pthread.h>
 #endif
 
+#ifndef HAVE_POSIX_MEMALIGN
+# ifdef HAVE_MEMALIGN
+#  include <malloc.h>
+# endif
+#endif
+
 #include <string.h>
 #include <argus_compat.h>
 
@@ -98,6 +114,9 @@ struct rtentry;         /* declarations in <net/if.h> */
 
 
 extern char *ArgusProgramName;
+#ifdef HAVE_BACKTRACE
+extern void ArgusBacktrace (void);
+#endif
 
 void ArgusInitAddrtoname(struct ArgusParserStruct *, u_int, u_int);
 void ArgusInitServarray(struct ArgusParserStruct *);
@@ -179,16 +198,19 @@ ArgusDebug (int d, char *fmt, ...)
 {
    struct timeval now;
    extern int Argusdflag, daemonflag;
-   char buf[MAXSTRLEN], *ptr;
+   char *buf = NULL, *ptr;
    va_list ap;
 
    if (d <= Argusdflag) {
       va_start (ap, fmt);
 
+      if ((buf = ArgusCalloc (1, MAXSTRLEN)) == NULL)
+         ArgusLog (LOG_ERR, "ArgusNewDump: ArgusCalloc error %s\n", strerror(errno));
+      ptr = buf;
+
       gettimeofday (&now, 0L);
 
 #if defined(ARGUS_THREADS)
-      pthread_mutex_lock(&ArgusMainLock);
       {
          pthread_t ptid;
          char pbuf[128];
@@ -217,8 +239,6 @@ ArgusDebug (int d, char *fmt, ...)
 #endif
       } else
          fprintf (stderr, "%s", buf);
-
-      pthread_mutex_unlock(&ArgusMainLock);
 #else
       (void) snprintf (buf, MAXSTRLEN, "%s[%d]: %s ", ArgusProgramName, (int)getpid(), print_time(&now));
       ptr = &buf[strlen(buf)];
@@ -238,6 +258,10 @@ ArgusDebug (int d, char *fmt, ...)
       } else
          fprintf (stderr, "%s", buf);
 #endif
+
+      if (buf != NULL)
+         ArgusFree(buf);
+
       va_end (ap);
    }
 }
@@ -272,7 +296,6 @@ strtof (char *str, char **ptr)
 #endif
 
 void ArgusPrintHex (const u_char *, u_int);
-
 #if !defined(ntohll)
   #if defined(_LITTLE_ENDIAN)
     #if defined(__FreeBSD__) || defined(__NetBSD__) || defined(__OpenBSD__) || defined(__sun__)
@@ -303,6 +326,21 @@ ArgusHtoN (struct ArgusRecord *argus)
 
    switch (argus->hdr.type & 0xF0) {
       case ARGUS_MAR: {
+         switch (argus->argus_mar.status & (ARGUS_IDIS_STRING | ARGUS_IDIS_INT | ARGUS_IDIS_IPV4)) {
+            case ARGUS_IDIS_STRING: 
+            case ARGUS_IDIS_IPV6:
+            case ARGUS_IDIS_UUID:
+               break;
+
+            case ARGUS_IDIS_INT: {
+               argus->argus_mar.value = htonl(argus->argus_mar.value);
+               break;
+            }
+            case ARGUS_IDIS_IPV4: {
+               argus->argus_mar.ipv4 = htonl(argus->argus_mar.ipv4);
+               break;
+            }
+         }
          argus->argus_mar.status            = htonl(argus->argus_mar.status);
          argus->argus_mar.argusid           = htonl(argus->argus_mar.argusid);
          argus->argus_mar.localnet          = htonl(argus->argus_mar.localnet);
@@ -328,7 +366,6 @@ ArgusHtoN (struct ArgusRecord *argus)
          argus->argus_mar.bufs              = htonl(argus->argus_mar.bufs);
          argus->argus_mar.bytes             = htonl(argus->argus_mar.bytes);
 
-         argus->argus_mar.thisid            = htonl(argus->argus_mar.thisid);
          argus->argus_mar.record_len        = htonl(argus->argus_mar.record_len);
          break;
       }
@@ -375,11 +412,6 @@ ArgusHtoN (struct ArgusRecord *argus)
                                           flow->ipv6_flow.sport = htons(flow->ipv6_flow.sport);
                                           flow->ipv6_flow.dport = htons(flow->ipv6_flow.dport);
                                           break;
-
-                                       case IPPROTO_ICMPV6:
-                                          flow->icmpv6_flow.id = htons(flow->icmpv6_flow.id);
-                                          break;
-
                                        case IPPROTO_ESP:
                                           flow->esp6_flow.spi = htonl(flow->esp6_flow.spi);
                                           break;
@@ -466,10 +498,21 @@ ArgusHtoN (struct ArgusRecord *argus)
                      break;
                   }
 
+                  case ARGUS_FLOW_HASH_DSR: {
+                     struct ArgusFlowHashStruct *hash = (struct ArgusFlowHashStruct *) dsr;
+                     hash->hash = htonl(hash->hash);
+                     hash->ind = htonl(hash->ind);
+                     break;
+                  }
+
                   case ARGUS_ENCAPS_DSR: {
                      struct ArgusEncapsStruct *encaps = (struct ArgusEncapsStruct *) dsr;
                      encaps->src = htonl(encaps->src);
                      encaps->dst = htonl(encaps->dst);
+                     if (encaps->hdr.argus_dsrvl8.len > 3) {
+                        encaps->slen = htons(encaps->slen);
+                        encaps->dlen = htons(encaps->dlen);
+                     }
                      break;
                   }
 
@@ -511,25 +554,33 @@ ArgusHtoN (struct ArgusRecord *argus)
 
                   case ARGUS_TRANSPORT_DSR: {
                      struct ArgusTransportStruct *trans = (struct ArgusTransportStruct *) dsr;
-
-                     if (trans->hdr.subtype & ARGUS_SEQ)
-                           trans->seqnum = htonl(trans->seqnum);
+                     unsigned int *iptr = (unsigned int *)&trans->srcid.a_un.value;
 
                      if (trans->hdr.subtype & ARGUS_SRCID) {
-                        switch (trans->hdr.argus_dsrvl8.qual) {
+                        switch (trans->hdr.argus_dsrvl8.qual & ~ARGUS_TYPE_INTERFACE) {
                            case ARGUS_TYPE_INT:
-                              trans->srcid.a_un.value = htonl(trans->srcid.a_un.value);
-                              break;
                            case ARGUS_TYPE_IPV4:
-                              trans->srcid.a_un.value = htonl(trans->srcid.a_un.value);
+                              *iptr = htonl(*iptr);
+                              iptr += 1;
                               break;
 
+                           case ARGUS_TYPE_UUID:
                            case ARGUS_TYPE_IPV6:
+                              iptr += 4;
+                              break;
                            case ARGUS_TYPE_ETHER:
+                              iptr += 2;
+                              break;
                            case ARGUS_TYPE_STRING:
+                              iptr += 1;
                               break;
                         }
+                        if (trans->hdr.argus_dsrvl8.qual & ARGUS_TYPE_INTERFACE)
+                           iptr += 1;
                      }
+
+                     if (trans->hdr.subtype & ARGUS_SEQ)
+                        *iptr = htonl(*iptr);
                      break;
                   }
 
@@ -689,6 +740,7 @@ ArgusHtoN (struct ArgusRecord *argus)
                            tcp->seqbase      = htonl(tcp->seqbase);
                            tcp->options      = htonl(tcp->options);
                            tcp->win          = htons(tcp->win);
+                           tcp->maxseg       = htons(tcp->maxseg);
                            break;
                         }
                         case ARGUS_TCP_STATUS: {
@@ -716,6 +768,7 @@ ArgusHtoN (struct ArgusRecord *argus)
                            tcp->src.ackbytes = htonl(tcp->src.ackbytes);
                            tcp->src.winbytes = htonl(tcp->src.winbytes);
                            tcp->src.win = htons(tcp->src.win);
+                           tcp->src.maxseg = htons(tcp->src.maxseg);
 
                            if (dsr->argus_dsrvl8.len > (((sizeof(struct ArgusTCPObject) - sizeof(struct ArgusTCPObjectMetrics))+3)/4 + 1)) {
                               tcp->dst.lasttime.tv_sec  = htonl(tcp->dst.lasttime.tv_sec);
@@ -730,6 +783,7 @@ ArgusHtoN (struct ArgusRecord *argus)
                               tcp->dst.ackbytes = htonl(tcp->dst.ackbytes);
                               tcp->dst.winbytes = htonl(tcp->dst.winbytes);
                               tcp->dst.win = htons(tcp->dst.win);
+                              tcp->dst.maxseg = htons(tcp->dst.maxseg);
                            }
                            break;
                         }
@@ -782,6 +836,27 @@ ArgusHtoN (struct ArgusRecord *argus)
                      break;
                   }
 
+                  case ARGUS_GRE_DSR: {
+                     struct ArgusGreStruct *gre = (struct ArgusGreStruct *) dsr;
+                     gre->flags = htons(gre->flags);
+                     gre->proto = htons(gre->proto);
+                     break;
+                  }
+
+                  case ARGUS_VXLAN_DSR: {
+                     struct ArgusVxLanStruct *vlan = (struct ArgusVxLanStruct *) dsr;
+                     vlan->svnid = htonl(vlan->svnid);
+                     vlan->dvnid = htonl(vlan->dvnid);
+                     break;
+                  }
+
+                  case ARGUS_GENEVE_DSR: {
+                     struct ArgusGeneveStruct *gen = (struct ArgusGeneveStruct *) dsr;
+                     gen->ptype = htons(gen->ptype);
+                     gen->vni = htonl(gen->vni);
+                     break;
+                  }
+
                   case ARGUS_MPLS_DSR: {
                      struct ArgusMplsStruct *mpls = (struct ArgusMplsStruct *) dsr;
                      unsigned int *label = (unsigned int *)(dsr + 1);
@@ -893,6 +968,7 @@ ArgusPrintHex (const u_char *bp, u_int length)
 
 
 char *ArgusProcessStr = NULL;
+void ArgusPrintDirection (char *, struct ArgusRecordStruct *, int);
 
 void
 ArgusPrintDirection (char *buf, struct ArgusRecordStruct *argus, int len)
@@ -1002,10 +1078,13 @@ ArgusPrintDirection (char *buf, struct ArgusRecordStruct *argus, int len)
 }
 
 
-int ArgusAllocMax   = 0;
-int ArgusAllocBytes = 0;
-int ArgusAllocTotal = 0;
-int ArgusFreeTotal  = 0;
+#if defined(ARGUSMEMDEBUG)
+long long ArgusAllocMax   = 0;
+long long ArgusAllocBytes = 0;
+#endif
+
+long long ArgusAllocTotal = 0;
+long long ArgusFreeTotal  = 0;
 
 struct ArgusMemoryList memory = {NULL, 0};
 
@@ -1014,21 +1093,24 @@ struct ArgusMemoryList memory = {NULL, 0};
 #define ARGUS_ALIGN	128
 */
 
-void *     
-ArgusMalloc (int bytes) 
+typedef void *(*allocator_func)(size_t, void *);
+
+static void *
+__argus_malloc (int bytes, allocator_func alloc, void *aux)
 {          
    void *retn = NULL; 
    int offset;
  
    if (bytes) {
-      if (ArgusAllocTotal++ == 0) {
 #if defined(ARGUS_THREADS)
-         pthread_mutex_init(&memory.lock, NULL);
+      pthread_mutex_lock(&memory.lock);
 #endif
-      }
+      ArgusAllocTotal++;
+#if defined(ARGUSMEMDEBUG)
       ArgusAllocBytes += bytes;
       if (ArgusAllocMax < ArgusAllocBytes)
          ArgusAllocMax = ArgusAllocBytes;
+#endif
 
 #if defined(ARGUS_ALIGN)
       offset = ARGUS_ALIGN;
@@ -1037,9 +1119,9 @@ ArgusMalloc (int bytes)
 #endif
 
 #if !defined(ARGUSMEMDEBUG)
-      retn = (void *) malloc (bytes + offset);
+      retn = (void *) alloc(bytes + offset, aux);
 #else
-      if ((retn = (u_int *) malloc (bytes + sizeof(struct ArgusMemoryHeader) + offset)) != NULL) {
+      if ((retn = (u_int *) alloc(bytes + sizeof(struct ArgusMemoryHeader) + offset, aux)) != NULL) {
          struct ArgusMemoryHeader *mem = (struct ArgusMemoryHeader *)retn;
          mem->tag = ARGUS_ALLOC;
          mem->len = bytes;
@@ -1048,9 +1130,6 @@ ArgusMalloc (int bytes)
          mem->frame[0] = __builtin_return_address(0);
          mem->frame[1] = __builtin_return_address(1);
          mem->frame[2] = __builtin_return_address(2);
-#endif
-#if defined(ARGUS_THREADS)
-         pthread_mutex_lock(&memory.lock);
 #endif
          if (memory.start) {
             mem->nxt = memory.start;
@@ -1066,9 +1145,6 @@ ArgusMalloc (int bytes)
          }
          memory.count++;
          memory.total++;
-#if defined(ARGUS_THREADS)
-         pthread_mutex_unlock(&memory.lock);
-#endif
          retn = (void *)(mem + 1);
       }
 #endif
@@ -1082,90 +1158,70 @@ ArgusMalloc (int bytes)
          ((unsigned short *)retn)[-1] = toff;
       }
 #endif
-   }
-#ifdef ARGUSDEBUG
-   ArgusDebug (6, "ArgusMalloc (%d) returning %p\n", bytes, retn); 
+#if defined(ARGUS_THREADS)
+      pthread_mutex_unlock(&memory.lock);
 #endif
+   }
    return (retn); 
 }
 
+static void *
+__malloc(size_t bytes, void *aux __attribute__((unused)))
+{
+   return malloc(bytes);
+}
+
+void *
+ArgusMalloc(int bytes)
+{
+   return __argus_malloc(bytes, __malloc, NULL);
+}
+
+static void *
+__calloc(size_t bytes, void *aux __attribute__((unused)))
+{
+   return calloc(1, bytes);
+}
+
 void *
 ArgusCalloc (int nitems, int bytes)
 {
-   int offset, total = nitems * bytes;
-   void *retn = NULL;
-
-   if (total) {
-      if (ArgusAllocTotal++ == 0) {
-#if defined(ARGUS_THREADS)
-         pthread_mutex_init(&memory.lock, NULL);
-#endif
-      }
-      ArgusAllocBytes += total;
-      if (ArgusAllocMax < ArgusAllocBytes)
-         ArgusAllocMax = ArgusAllocBytes;
-
-#if defined(ARGUS_ALIGN)
-      offset = ARGUS_ALIGN;
-#else
-      offset = 0;
-#endif
-
-#if !defined(ARGUSMEMDEBUG)
-      retn = calloc (1, total + offset);
-#else
-      if ((retn = calloc (1, total + sizeof(struct ArgusMemoryHeader) + offset)) != NULL) {
-         struct ArgusMemoryHeader *mem = retn;
-         mem->tag = ARGUS_ALLOC;
-         mem->len = total;
-         mem->offset = offset;
-#if defined(__GNUC__)
-         mem->frame[0] = __builtin_return_address(0);
-         mem->frame[1] = __builtin_return_address(1);
-         mem->frame[2] = __builtin_return_address(2);
-#endif
-
-#if defined(ARGUS_THREADS)
-         pthread_mutex_lock(&memory.lock);
-#endif
-         if (memory.start) {
-            mem->nxt = memory.start;
-            mem->prv = memory.start->prv;
-            mem->prv->nxt = mem;
-            mem->nxt->prv = mem;
-            memory.end = mem;
-         } else {
-            memory.start = mem;
-            memory.end = mem;
-            mem->nxt = mem;
-            mem->prv = mem;
-         }
-         memory.total++;
-         memory.count++;
-#if defined(ARGUS_THREADS)
-         pthread_mutex_unlock(&memory.lock);
-#endif
-         retn = (void *)(mem + 1);
-      }
-#endif
-
-#if defined(ARGUS_ALIGN)
-      if (retn != NULL) {
-         unsigned short toff;
-         toff = ((unsigned long)retn & (offset - 1));
-         toff = offset - toff;
-         retn = (void *)((char *)retn + toff);
-         ((unsigned short *)retn)[-1] = toff;
-      }
-#endif
-   }
-
-#ifdef ARGUSDEBUG
-   ArgusDebug (6, "ArgusCalloc (%d, %d) returning %p\n", nitems, bytes, retn);
-#endif
+   int total = nitems * bytes;
+   void *retn = __argus_malloc(total, __calloc, NULL);
    return (retn);
 }
 
+static void *
+__malloc_aligned(size_t bytes, void *aux)
+{
+    void *mem;
+    size_t alignment = *(size_t *)aux;
+#if defined(HAVE_POSIX_MEMALIGN)
+    int res = posix_memalign(&mem, alignment, bytes);
+#else
+    int res = -1;
+
+# if defined(HAVE_MEMALIGN)
+    mem = memalign(alignment, bytes);
+# else
+    mem = malloc(bytes);
+# endif
+    if (mem)
+       res = 0;
+#endif
+
+    if (res == 0)
+       return mem;
+
+    return NULL;
+}
+
+void *
+ArgusMallocAligned(int bytes, size_t alignment)
+{
+   return __argus_malloc(bytes, __malloc_aligned, &alignment);
+}
+
 
 void
 ArgusFree (void *buf)
@@ -1173,6 +1229,9 @@ ArgusFree (void *buf)
    void *ptr = buf;
 
    if (ptr) {
+#if defined(ARGUS_THREADS)
+      pthread_mutex_lock(&memory.lock);
+#endif
       ArgusFreeTotal++;
 #if defined(ARGUSMEMDEBUG)
       {
@@ -1183,11 +1242,8 @@ ArgusFree (void *buf)
 #endif
          mem--;
          if (mem->tag != ARGUS_ALLOC)
-            ArgusLog (LOG_ERR, "ArgusFree: buffer error %p", ptr);
+            ArgusLog (LOG_ERR, "ArgusFree: buffer error 0x%x", ptr);
 
-#if defined(ARGUS_THREADS)
-         pthread_mutex_lock(&memory.lock);
-#endif
          if (memory.count == 1) {
             memory.start = NULL;
             memory.end = NULL;
@@ -1202,9 +1258,6 @@ ArgusFree (void *buf)
          }
          ArgusAllocBytes -= mem->len;
          memory.count--;
-#if defined(ARGUS_THREADS)
-         pthread_mutex_unlock(&memory.lock);
-#endif
          ptr = mem;
       }
 #else
@@ -1217,12 +1270,13 @@ ArgusFree (void *buf)
 #endif
 #endif
       free (ptr);
+      if (ArgusAllocTotal > 0)
+         ArgusAllocTotal--;
    }
-#ifdef ARGUSDEBUG
-   ArgusDebug (6, "ArgusFree (%p)\n", buf);
+#if defined(ARGUS_THREADS)
+      pthread_mutex_unlock(&memory.lock);
 #endif
 }
-
 /* 
    the argus malloc list is the list of free MallocLists for the system.
    these are blocks that are used to convey flow data from the modeler
@@ -1297,9 +1351,6 @@ ArgusInitMallocList (int length)
       pthread_mutex_unlock(&ArgusModel->lock);
 #endif
 
-#ifdef ARGUSDEBUG 
-   ArgusDebug (6, "ArgusInitMallocList (%d) returning\n", length);
-#endif
    return;
 }
 
@@ -1383,9 +1434,6 @@ ArgusMallocListRecord (int length)
    if (mem != NULL)
       retn = (void *)(mem + 1);
 
-#ifdef ARGUSDEBUG
-   ArgusDebug (8, "ArgusMallocListRecord (%d) returning %p total %d out %d\n", length, retn, ArgusMallocList->total, ArgusMallocList->out);
-#endif
    return (retn);
 }
 
@@ -1482,7 +1530,16 @@ struct ArgusLogPriorityStruct ArgusPriorityStr[ARGUSPRIORITYSTR] =
    { LOG_DEBUG,   "    ArgusDebug" },
 };
 
-      
+/* log level for non-syslog display (stderr) */
+static int ArgusLogDisplayPriority = LOG_WARNING;
+
+void setArgusLogDisplayPriority(int prio)
+{
+   if (prio < LOG_EMERG || prio > LOG_DEBUG)
+      return;
+
+   ArgusLogDisplayPriority = prio;
+}
 
 #include <sys/time.h>
 
@@ -1527,7 +1584,7 @@ ArgusLog (int priority, char *fmt, ...)
 #ifdef HAVE_SYSLOG
       syslog (priority, "%s", buf);
 #endif
-   } else {
+   } else if (priority <= ArgusLogDisplayPriority) {
       char *label = NULL;
       int i;
       if (*fmt) {
@@ -1547,7 +1604,9 @@ ArgusLog (int priority, char *fmt, ...)
 
    switch (priority) {
       case LOG_ERR:
+#ifdef HAVE_BACKTRACE
           ArgusBacktrace();
+#endif
           exit(1);
 
       default: break;
@@ -1556,7 +1615,7 @@ ArgusLog (int priority, char *fmt, ...)
 
 
 void ArgusRecordDump (struct ArgusRecord *);
-void ArgusDump (const u_char *, int);
+void ArgusDumpBuffer (const u_char *, int);
 
 #define HEXDUMP_BYTES_PER_LINE 16
 #define HEXDUMP_SHORTS_PER_LINE (HEXDUMP_BYTES_PER_LINE / 2)
@@ -1571,14 +1630,14 @@ ArgusRecordDump (struct ArgusRecord *argus)
    int length = argus->hdr.len;
    const u_char *cp = (const u_char *) argus;
 
-   ArgusDump (cp, length);
+   ArgusDumpBuffer (cp, length);
 }
 
 
 #include <ctype.h>
 
 void
-ArgusDump (const u_char *cp, int length)
+ArgusDumpBuffer (const u_char *cp, int length)
 {
    u_int oset = 0;
    register u_int i;
@@ -1588,7 +1647,7 @@ ArgusDump (const u_char *cp, int length)
    char asciistuff[HEXDUMP_BYTES_PER_LINE+1], *asp;
 
 #ifdef ARGUSDEBUG
-   ArgusDebug (2, "ArgusDump (%p, %d)\n", cp, length);
+   ArgusDebug (2, "ArgusDumpBuffer (%p, %d)\n", cp, length);
 #endif
 
    nshorts = length / sizeof(u_short);
@@ -1798,9 +1857,8 @@ ArgusInitServarray(struct ArgusParserStruct *parser)
       table->addr = port;
       table->nxt = (struct hnamemem *)calloc(1, sizeof(*table));
    }
-
-   parser->ArgusSrvInit = 1;
    endservent();
+   parser->ArgusSrvInit = 1;
 #endif
 }
 
@@ -1817,7 +1875,7 @@ ArgusFreeServarray(struct ArgusParserStruct *parser)
             case 1: table = parser->uporttable; break;
          }
 
-         if ((struct hnamemem *)&table[i].name != NULL) {
+         if (table[i].name != NULL) {
             struct hnamemem *tp, *sp;
             free(table[i].name);
             if ((tp = (struct hnamemem *)table[i].nxt) != NULL) {
@@ -2548,7 +2606,7 @@ RaParseCIDRAddr (struct ArgusParserStruct *parser, char *addr)
 
       case AF_INET6: {
          unsigned short *val = (unsigned short *)&retn->addr;
-         int ind = 0, len = sizeof(retn->addr)/sizeof(unsigned short);
+         int ind = 0, len = sizeof(retn->addr)/(sizeof(unsigned short));
          int fsecnum = 8, lsecnum = 0, rsecnum = 0, i, masklen;
          char *sstr = NULL, *ipv4addr = NULL;
 
