@@ -405,7 +405,8 @@ struct ieee80211_radiotap_header {
 					 * Additional extensions are made
 					 * by setting bit 31.
 					 */
-} __attribute__((__packed__, __aligned__(8)));
+//} __attribute__((__packed__, __aligned__(2)));
+};
 
 
 struct ieee80211_xchannel {
