@@ -1,3 +1,28 @@
+/*
+ * Argus-5.0 Software.  Common include files. Llc defines
+ * Copyright (c) 2000-2024 QoSient, LLC
+ * All rights reserved.
+ *
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
+ */
 /*
  * Copyright (c) 1993, 1994, 1997
  *	The Regents of the University of California.  All rights reserved.
@@ -21,9 +46,9 @@
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_llc.h#4 $
- * $DateTime: 2011/01/26 17:11:49 $
- * $Change: 2087 $
+ * $Id: //depot/gargoyle/argus/include/argus_llc.h#3 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
  */
 
 #if !defined(Argus_llc_h)
@@ -39,22 +64,22 @@
  * A somewhat abstracted view of the LLC header
  */
 
-struct llc {
-	u_char dsap;
-	u_char ssap;
-	union {
-		u_char u_ctl;
-		u_short is_ctl;
-		struct {
-			u_char snap_ui;
-			u_char snap_pi[5];
-		} snap;
-		struct {
-			u_char snap_ui;
-			u_char snap_orgcode[3];
-			u_char snap_ethertype[2];
-		} snap_ether;
-	} ctl;
+struct argus_llc {
+   u_char dsap;
+   u_char ssap;
+   union {
+      u_char u_ctl;
+      u_short is_ctl;
+      struct {
+         u_char snap_ui;
+         u_char snap_pi[5];
+      } snap;
+      struct {
+         u_char snap_ui;
+         u_char snap_orgcode[3];
+         u_char snap_ethertype[2];
+      } snap_ether;
+   } ctl;
 };
 
 #define	llcui		ctl.snap.snap_ui
