@@ -1,28 +1,33 @@
 /*
- * Argus Software
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common include files. OS Specific defines
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- 
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_os.h#20 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/gargoyle/argus/include/argus_os.h#5 $
+ * $DateTime: 2015/04/13 00:39:28 $
+ * $Change: 2980 $
  */
 
 #ifndef ArgusOs_h
@@ -219,6 +224,34 @@ typedef uint64_t u_int64_t;
 #define ICMP_PARAMETERPROB	12	/* Parameter Problem	*/
 #endif
 
+#if !defined(PCAP_IF_LOOPBACK)
+#define PCAP_IF_LOOPBACK                          0x00000001      /* interface is loopback */
+#endif
+#if !defined(PCAP_IF_UP)
+#define PCAP_IF_UP                                0x00000002      /* interface is up */
+#endif
+#if !defined(PCAP_IF_RUNNING)
+#define PCAP_IF_RUNNING                           0x00000004      /* interface is running */
+#endif
+#if !defined(PCAP_IF_WIRELESS)
+#define PCAP_IF_WIRELESS                          0x00000008      /* interface is wireless (*NOT* necessarily Wi-Fi!) */
+#endif
+#if !defined(PCAP_IF_CONNECTION_STATUS)
+#define PCAP_IF_CONNECTION_STATUS                 0x00000030      /* connection status: */
+#endif
+#if !defined(PCAP_IF_CONNECTION_STATUS_UNKNOWN)
+#define PCAP_IF_CONNECTION_STATUS_UNKNOWN         0x00000000      /* unknown */
+#endif
+#if !defined(PCAP_IF_CONNECTION_STATUS_CONNECTED)
+#define PCAP_IF_CONNECTION_STATUS_CONNECTED       0x00000010      /* connected */
+#endif
+#if !defined(PCAP_IF_CONNECTION_STATUS_DISCONNECTED)
+#define PCAP_IF_CONNECTION_STATUS_DISCONNECTED    0x00000020      /* disconnected */
+#endif
+#if !defined(PCAP_IF_CONNECTION_STATUS_NOT_APPLICABLE)
+#define PCAP_IF_CONNECTION_STATUS_NOT_APPLICABLE  0x00000030      /* not applicable */
+#endif
+
 #ifdef __cplusplus
 }
 #endif
