@@ -1,28 +1,33 @@
 /*
- * Argus Software Common include files -  output structures
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common include files. Output structures
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- 
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_out.h#53 $
- * $DateTime: 2015/08/05 22:33:18 $
- * $Change: 3042 $
+ * $Id: //depot/gargoyle/argus/include/argus_out.h#13 $
+ * $DateTime: 2016/09/18 16:32:53 $
+ * $Change: 3186 $
  */
 
 
@@ -46,6 +51,8 @@
 #include <netinet/if_ether.h>
 #include <netinet/rtp.h>
 
+#include <argus_gre.h>
+#include <argus_geneve.h>
 #include <argus_llc.h>
 #include <argus_isis.h>
 #include <argus_udt.h>
@@ -115,6 +122,7 @@ struct ArgusTCPInitStatus {
    unsigned int options;
    unsigned short win; 
    unsigned char flags, winshift;
+   unsigned short maxseg, pad; 
 };
 
 struct ArgusTCPStatus {
@@ -128,6 +136,8 @@ struct ArgusTCPObjectMetrics {
    unsigned int bytes, retrans, ackbytes, winbytes;
    unsigned short win;
    unsigned char flags, winshift;
+   unsigned short maxseg, pad; 
+// unsigned int dup;
 };
  
 struct ArgusTCPObject {
@@ -468,6 +478,7 @@ struct ArgusIPv6Flow {
    unsigned int flow:20;
 #endif
    unsigned short sport, dport;
+   unsigned short smask, dmask;
 };
 
 struct ArgusUdtFlow {
@@ -543,17 +554,36 @@ struct ArgusSystemFlow {
 #define    wlan_flow flow_un.wlan
 #define     udt_flow flow_un.udt
 
+struct ArgusFlowHashStruct {
+   struct ArgusDSRHeader hdr;
+   unsigned int hash;
+   unsigned int ind;
+};
 
 struct ArgusAddrStruct {
    union {
       unsigned int value;
       unsigned int ipv4;
-      char str[4];
-/*
-      unsigned int ipv6[4];
       unsigned char ethersrc[6];
-*/
+      unsigned char str[4];
+      unsigned char uuid[16];
+      unsigned int ipv6[4];
    } a_un;
+   unsigned char inf[4];
+};
+
+struct ArgusV3AddrStruct {
+   union {
+      unsigned int value;
+      unsigned int ipv4;
+      unsigned char str[4];
+   } a_un;
+};
+
+struct ArgusV3TransportStruct {
+   struct ArgusDSRHeader hdr;
+   struct ArgusV3AddrStruct srcid;
+   unsigned int seqnum;
 };
 
 struct ArgusTransportStruct {
@@ -569,6 +599,8 @@ struct ArgusTimeStruct {
 struct ArgusEncapsStruct {
    struct ArgusDSRHeader hdr;
    unsigned int src, dst;
+   unsigned short slen, dlen;
+   char *sbuf, *dbuf;
 };
 
 struct ArgusTimeObject {
@@ -587,6 +619,21 @@ struct ArgusEventTimeStruct {
    unsigned int duration;
 };
 
+/*
+   ARGUS_HISTO_LINEAR       size:bins:start
+   ARGUS_HISTO_EXPONENTIAL  size:bins:start:base
+   ARGUS_HISTO_SCALED
+   ARGUS_HISTO_OUTLAYER_LOWER     
+   ARGUS_HISTO_OUTLAYER_UPPER     
+*/
+
+struct ArgusHistoObject {
+   struct ArgusDSRHeader hdr;
+   float size;
+   char bins, bits;
+   short start;
+   unsigned char *data;
+};
 
 struct ArgusUniStats {
    long long pkts, bytes, appbytes;
@@ -607,6 +654,22 @@ struct ArgusStatsObject {
    float meanval;
    float stdev;
    float maxval;
+   union {
+      unsigned int exp;
+      unsigned int *linear;
+   } dist_union;
+};
+
+struct ArgusOutputStatObject {
+   int n;
+   float minval;
+   float meanval;
+   float stdev;
+   float maxval;
+   union {
+      unsigned char fdist[8];
+      struct ArgusHistoObject linear;
+   } dist_union;
 };
 
 struct ArgusAgrStruct {
@@ -619,6 +682,7 @@ struct ArgusAgrStruct {
 
 struct ArgusPacketSizeObject {
    unsigned short psizemin, psizemax;
+   unsigned char psize[8];
 };
 
 struct ArgusPacketSizeStruct {
@@ -627,18 +691,24 @@ struct ArgusPacketSizeStruct {
 };
 
 struct ArgusJitterObject {
-   struct ArgusStatsObject src, dst;
+   struct ArgusStatObject act, idle;
 };
 
 struct ArgusJitterStruct {
    struct ArgusDSRHeader hdr;
-   struct ArgusJitterObject act, idle;
+   struct ArgusJitterObject src, dst;
 };
 
 struct ArgusMacStruct {
    struct ArgusDSRHeader hdr;
    struct ArgusMacFlow mac;
 };
+
+struct ArgusVxLanStruct {
+   struct ArgusDSRHeader hdr;
+   unsigned int svnid, dvnid;
+   struct ArgusFlow tflow;
+};
    
 struct ArgusVlanStruct {
    struct ArgusDSRHeader hdr;
@@ -651,6 +721,20 @@ struct ArgusMplsStruct {
    unsigned int dlabel;
 }; 
 
+struct ArgusGreStruct {
+   struct ArgusDSRHeader hdr;
+   unsigned short flags, proto;
+   struct ArgusFlow tflow;
+};
+
+struct ArgusGeneveStruct {
+   struct ArgusDSRHeader hdr;
+   unsigned char ver_opt, flags;
+   unsigned short ptype;
+   unsigned int vni;
+   struct ArgusFlow tflow;
+};
+
 struct ArgusIPAttrStruct {
    struct ArgusDSRHeader hdr;
    struct ArgusIPAttrObject src, dst;
@@ -769,6 +853,41 @@ struct ArgusEventStruct {
 
 
 struct ArgusMarStruct {
+   unsigned int status, argusid;
+   unsigned int localnet, netmask;
+   unsigned int nextMrSequenceNum;
+   struct ArgusTime startime, now;
+
+   unsigned char  major_version, minor_version;
+   unsigned char interfaceType, interfaceStatus;
+   unsigned short reportInterval, argusMrInterval;
+
+   unsigned long long pktsRcvd, bytesRcvd;
+   long long drift;
+
+   unsigned int records, flows, dropped;
+   unsigned int queue, output, clients;
+   unsigned int bufs, bytes;
+   unsigned short suserlen, duserlen;
+
+   union {
+      unsigned int value;
+      unsigned int ipv4;
+      unsigned char ethersrc[6];
+      unsigned char str[4];
+      unsigned char uuid[16];
+      unsigned int ipv6[4];
+      struct {
+         unsigned int pad[3];
+         unsigned int thisid;
+      };
+   };
+
+   unsigned int record_len;
+};
+
+
+struct ArgusV3MarStruct {
    unsigned int status, argusid;
    unsigned int localnet, netmask, nextMrSequenceNum;
    struct ArgusTime startime, now;
@@ -787,11 +906,54 @@ struct ArgusMarStruct {
 };
 
 struct ArgusMarSupStruct {
-   unsigned int status, argusid;
+   unsigned int status;
+   unsigned char argusid[16];
    struct ArgusTime startime, now;
    struct ArgusInputStruct input;
 };
 
+
+#define ARGUS_L2_ADDRESS	0x01
+#define ARGUS_IPV4_ADDRESS	0x02
+#define ARGUS_IPV6_ADDRESS	0x03
+
+struct ArgusIPv4Addr {
+   unsigned int addr, mask;
+};
+
+struct ArgusIPv6Addr {
+   unsigned int addr[4];
+   unsigned int prefixlen;
+};
+
+struct ArgusAddressStruct {
+   unsigned char type, length;
+   unsigned short status;
+
+   union {
+      struct ArgusHAddr    l2addr;
+      struct ArgusIPv4Addr ipv4;
+      struct ArgusIPv6Addr ipv6;
+   } addr;
+};
+
+
+struct ArgusMarInterfaceStruct {
+   unsigned char type, length;
+   unsigned short status;
+
+   unsigned char inf[4];
+   int flags, mtu;
+   struct ArgusAddressStruct *addr;
+};
+
+struct ArgusMarInfStruct {
+   unsigned int status;
+   struct ArgusAddrStruct srcid;
+   struct ArgusTime startime, now;
+   struct ArgusMarInterfaceStruct *inf;
+};
+
 struct ArgusFarStruct {
    struct ArgusFlow flow;
 };
@@ -819,6 +981,7 @@ struct ArgusRecord {
    struct ArgusRecordHeader hdr;
    union {
       struct ArgusMarStruct    mar;
+      struct ArgusMarInfStruct inf;
       struct ArgusMarSupStruct sup;
       struct ArgusFarStruct    far;
       struct ArgusEventStruct  event;
@@ -826,6 +989,7 @@ struct ArgusRecord {
 };
 
 #define argus_mar       ar_un.mar
+#define argus_inf       ar_un.inf
 #define argus_sup       ar_un.sup
 #define argus_far       ar_un.far
 #define argus_event     ar_un.event
@@ -864,6 +1028,7 @@ struct ArgusNetworkStruct {
 struct ArgusCanonRecord {
    struct ArgusRecordHeader      hdr;
    struct ArgusFlow              flow;
+   struct ArgusFlowHashStruct    hash;
    struct ArgusTransportStruct   trans;
    struct ArgusTimeObject        time;
    struct ArgusEncapsStruct      encaps;
@@ -871,6 +1036,9 @@ struct ArgusCanonRecord {
    struct ArgusIPAttrStruct      attr;
    struct ArgusMetricStruct      metric;
    struct ArgusNetworkStruct     net;
+   struct ArgusVxLanStruct       vxlan;
+   struct ArgusGreStruct         gre;
+   struct ArgusGeneveStruct      gen;
    struct ArgusMacStruct         mac;
    struct ArgusVlanStruct        vlan;
    struct ArgusMplsStruct        mpls;
