@@ -1,28 +1,33 @@
 /*
- * Argus Software.  Common include files - Utilities
- * Copyright (c) 2000-2020 QoSient, LLC
+ * Argus-5.0 Software.  Common include files. Utilities
+ * Copyright (c) 2000-2024 QoSient, LLC
  * All rights reserved.
  *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2, or (at your option)
- * any later version.
- 
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
-
+ * This program is free software, released under the GNU General
+ * Public License; you can redistribute it and/or modify it under the terms
+ * of the GNU General Public License as published by the Free Software
+ * Foundation; either version 3, or any later version.
+ *
+ * Other licenses are available through QoSient, LLC.
+ * Inquire at info@qosient.com.
+ *
+ * This program is distributed WITHOUT ANY WARRANTY; without even the
+ * implied warranty of * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+ * See the * GNU General Public License for more details.
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
+ * Written by Carter Bullard
+ * QoSient, LLC
+ *
  */
 
 /* 
- * $Id: //depot/argus/argus/include/argus_util.h#24 $
- * $DateTime: 2015/04/06 10:38:44 $
- * $Change: 2973 $
+ * $Id: //depot/gargoyle/argus/include/argus_util.h#6 $
+ * $DateTime: 2015/04/21 19:24:29 $
+ * $Change: 3018 $
  */
 
 #if !defined(Argus_util_h)
@@ -91,7 +96,7 @@ struct ArgusMemoryList {
 #define ARGUS_DATA_SOURCE		0x01
 #define ARGUS_CISCO_DATA_SOURCE		0x10
 #define ARGUS_SFLOW_DATA_SOURCE		0x20
-
+#define ARGUS_DOMAIN_SOURCE		0x100
 
 #define TSEQ_HASHSIZE      9029
 
@@ -150,6 +155,7 @@ extern char  RaFieldDelimiter;
 
 void *ArgusMalloc (int);
 void *ArgusCalloc (int, int);
+void *ArgusMallocAligned(int, size_t);
 void ArgusFree (void *);
 void ArgusFreeListRecord (void *buf);
 void ArgusInitMallocList (int length);
@@ -157,6 +163,7 @@ void ArgusDeleteMallocList (void);
 void *ArgusMallocListRecord (int length);
 
 void ArgusLog (int, char *, ...);
+void setArgusLogDisplayPriority(int);
 
 void ArgusInitServarray(struct ArgusParserStruct *);
 
@@ -166,6 +173,7 @@ extern void ArgusAdjustGlobalTime (struct timeval *);
 
 extern void *ArgusMalloc (int);
 extern void *ArgusCalloc (int, int);
+void *ArgusMallocAligned(int, size_t);
 extern void ArgusFree (void *);
 extern void ArgusFreeListRecord (void *buf);
 extern void ArgusInitMallocList (int length);
@@ -173,6 +181,7 @@ extern void ArgusDeleteMallocList (void);
 extern void *ArgusMallocListRecord (int length);
 
 extern void ArgusLog (int, char *, ...);
+extern void setArgusLogDisplayPriority (int);
 
 #endif 
 #endif /* Argus_util_h */
